package edu.zju.bme.tumorboard.config;

/**
 * @author Nie.YunFeng
 * @date 2021/2/4
 */

import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.SqlSessionTemplate;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.jdbc.DataSourceBuilder;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

import javax.sql.DataSource;

@Configuration
@MapperScan(basePackages = "edu.zju.bme.tumorboard.mapper.cdr", sqlSessionTemplateRef = "cdrSqlSessionTemplate")
public class CdrMybatisConfig {
    @Bean
    @ConfigurationProperties(prefix = "spring.datasource.cdr")
    public DataSource cdrDataSource() {
        return DataSourceBuilder.create().build();
    }

    @Bean
    public SqlSessionFactory cdrSqlSessionFactory(@Qualifier("cdrDataSource") DataSource dataSource) throws Exception {
        SqlSessionFactoryBean bean = new SqlSessionFactoryBean();
        bean.setDataSource(dataSource);
        bean.setMapperLocations(new PathMatchingResourcePatternResolver().getResources("classpath:mapper/cdr/*.xml"));
        return bean.getObject();
    }

    @Bean
    public DataSourceTransactionManager cdrTransactionManager(@Qualifier("cdrDataSource") DataSource dataSource) {
        return new DataSourceTransactionManager(dataSource);
    }

    @Bean
    public SqlSessionTemplate cdrSqlSessionTemplate(@Qualifier("cdrSqlSessionFactory") SqlSessionFactory sqlSessionFactory) {
        return new SqlSessionTemplate(sqlSessionFactory);
    }
}
