package edu.zju.bme.tumorboard.config;

/**
 * 院内临床试验数据库
 *
 * @author Nie.YunFeng
 * @date 2021/3/29
 */

import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.SqlSessionTemplate;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.jdbc.DataSourceBuilder;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

import javax.sql.DataSource;

@Configuration
@MapperScan(basePackages = "edu.zju.bme.tumorboard.mapper.hospital", sqlSessionTemplateRef = "hospitalTestSqlSessionTemplate")
public class HospitalClinicalTestMybatisConfig {
    @Bean
    @ConfigurationProperties(prefix = "spring.datasource.hospital-clinical-test-db")
    public DataSource hospitalTestDataSource() {
        return DataSourceBuilder.create().build();
    }

    @Bean
    public SqlSessionFactory hospitalTestSqlSessionFactory(@Qualifier("hospitalTestDataSource") DataSource dataSource) throws Exception {
        SqlSessionFactoryBean bean = new SqlSessionFactoryBean();
        bean.setDataSource(dataSource);
        bean.setMapperLocations(new PathMatchingResourcePatternResolver().getResources("classpath:mapper/hospital/*.xml"));
        return bean.getObject();
    }

    @Bean
    public DataSourceTransactionManager hospitalTestTransactionManager(@Qualifier("hospitalTestDataSource") DataSource dataSource) {
        return new DataSourceTransactionManager(dataSource);
    }

    @Bean
    public SqlSessionTemplate hospitalTestSqlSessionTemplate(@Qualifier("hospitalTestSqlSessionFactory") SqlSessionFactory sqlSessionFactory) {
        return new SqlSessionTemplate(sqlSessionFactory);
    }
}
