package edu.zju.bme.tumorboard.controller;

/**
 * @author Meng.ZiZhong
 * @date 2021/2/6
 */

import edu.zju.bme.tumorboard.entity.ClinicalTestData;
import edu.zju.bme.tumorboard.entity.HospitalClinicalTestData;
import edu.zju.bme.tumorboard.entity.Patient;
import edu.zju.bme.tumorboard.entity.other.ClinicalTestDataFilterInfo;
import edu.zju.bme.tumorboard.service.ClinicalTestDataService;
import edu.zju.bme.tumorboard.utils.RestResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

@Slf4j
@RestController
@RequestMapping("/clinicalTestData")
@CrossOrigin
public class ClinicalTestDataController {
    @Autowired
    private ClinicalTestDataService clinicalTestDataService;

    @PostMapping("getByFilterInfo")
    @ApiOperation(value = "根据筛选信息获取临床实验信息")
    @ApiImplicitParam(name = "clinicalTestDataFilterInfo", value = "临床实验筛选信息", required = true, dataType = "临床实验筛选信息类")
    public RestResult getByFilterInfo(@RequestBody ClinicalTestDataFilterInfo clinicalTestDataFilterInfo) {
        return RestResult.ok(clinicalTestDataService.getByFilterInfo(clinicalTestDataFilterInfo));
    }

    @PostMapping("hospital/byFilterInfo")
    @ApiOperation(value = "根据筛选信息获取院内临床实验信息")
    @ApiImplicitParam(name = "hospitalClinicalTestData", value = "院内临床实验筛选信息", required = true, dataType = "院内临床实验类")
    public RestResult getHospitalTestDataByFilterInfo(@RequestBody HospitalClinicalTestData hospitalClinicalTestData,
                                                      @RequestParam("pageIndex") Integer pageIndex, @RequestParam("limitNumber") Integer limitNumber) {
        Map<String, Object> result = new HashMap<>();
        result.put("hospitalTestDataList", clinicalTestDataService.getHospitalTestByFilterInfo(hospitalClinicalTestData, pageIndex, limitNumber));
        result.put("total", clinicalTestDataService.countHospitalTestByFilterInfo(hospitalClinicalTestData));
        return RestResult.ok(result);
    }

    @PostMapping("delete")
    @ApiOperation(value = "删除临床实验信息")
    @ApiImplicitParam(name = "clinicalTestDataId", value = "临床实验信息ID", required = true, dataType = "String")
    public RestResult delete(@RequestBody String clinicalTestDataId) {
        return RestResult.ok(clinicalTestDataService.deleteByPrimaryKey(clinicalTestDataId));
    }

    @PostMapping("update")
    @ApiOperation(value = "更新临床实验信息")
    @ApiImplicitParam(name = "patient", value = "病人信息", required = true, dataType = "病人实体类")
    public RestResult update(@RequestBody ClinicalTestData clinicalTestData) {
        return RestResult.ok(clinicalTestDataService.updateByPrimaryKey(clinicalTestData));
    }

    @GetMapping("getSelectInfo")
    @ApiOperation(value = "获取查询信息")
    public RestResult getSelectInfo() {
        return RestResult.ok(clinicalTestDataService.getSelectInfo());
    }
}
