package edu.zju.bme.tumorboard.controller;

/**
 * @author Meng.ZiZhong
 * @date 2021/3/29
 */


import edu.zju.bme.tumorboard.entity.GeneGermlineVariant;
import edu.zju.bme.tumorboard.entity.GeneMutationInfo;
import edu.zju.bme.tumorboard.service.GeneMutationService;
import edu.zju.bme.tumorboard.utils.RestResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Slf4j
@RestController
@RequestMapping("/geneMutation")
@CrossOrigin
public class GeneMutationController {
    @Autowired
    private GeneMutationService geneMutationService;

    @GetMapping("getAll")
    @ApiOperation(value = "根据基因名称集合获取基因变异信息集合")
    @ApiImplicitParam(name = "geneNames", value = "基因名称集合", required = true, dataType = "List<String>")
    public RestResult getByFilterInfo(@RequestParam Integer pageIndex) {
        return RestResult.ok(geneMutationService.getAll(pageIndex) );
    }

    @PostMapping("getByGene")
    @ApiOperation(value = "根据基因名称集合获取基因变异信息集合")
    @ApiImplicitParam(name = "geneNames", value = "基因名称集合", required = true, dataType = "List<String>")
    public RestResult getByFilterInfo(@RequestBody List<String> geneNames, @RequestParam("pageIndex") Integer pageIndex) {
        return RestResult.ok(geneMutationService.getByGene(geneNames, pageIndex) );
    }

    @GetMapping("getByDrug")
    @ApiOperation(value = "根据药品名称获取基因变异信息集合")
    @ApiImplicitParam(name = "targetedDrugEn", value = "药品名称", required = true, dataType = "String")
    public RestResult getByFilterInfo(@RequestParam("targetedDrugEn") String targetedDrugEn, @RequestParam("pageIndex") Integer pageIndex) {
        return RestResult.ok(geneMutationService.getByDrug(targetedDrugEn, pageIndex) );
    }

    @GetMapping("getSelectInfo")
    @ApiOperation(value = "获取体细胞突变与靶向药物知识库查询信息")
    public RestResult getSelectInfo() {
        return RestResult.ok(geneMutationService.getSelectInfo() );
    }

    @PostMapping("getVariantSelectInfo")
    @ApiOperation(value = "获取胚系变异与化疗药物知识库查询信息")
    public RestResult getVariantSelectInfo(@RequestBody GeneGermlineVariant geneGermlineVariant) {
        return RestResult.ok(geneMutationService.getVariantSelectInfo(geneGermlineVariant));
    }

    @PostMapping("getVariantUnscrambleInfo")
    @ApiOperation(value = "获取胚系变异与化疗药物知识库信息")
    public RestResult getVariantUnscrambleInfo(@RequestBody GeneGermlineVariant geneGermlineVariant) {
        return RestResult.ok(geneMutationService.getVariantUnscrambleInfo(geneGermlineVariant));
    }

    @PostMapping("getGeneMutationByGeneTestInfo")
    @ApiOperation(value = "根据基因检测信息获取基因突变信息")
    public RestResult getGeneMutationByGeneTestInfoe(@RequestBody List<GeneMutationInfo> geneMutationTestInfoList, @RequestParam("pageIndex") Integer pageIndex) {
        return RestResult.ok(geneMutationService.getGeneMutationByGeneTestInfo(geneMutationTestInfoList, pageIndex));
    }

    @PostMapping("getGeneGermlineVariantByGeneTestInfo")
    @ApiOperation(value = "根据基因检测信息获取基因突变信息")
    public RestResult getGeneGermlineVariantByGeneTestInfo(@RequestBody List<GeneGermlineVariant> geneGermlineVariantList) {
        return RestResult.ok(geneMutationService.getGeneGermlineVariantByGeneTestInfo(geneGermlineVariantList));
    }
}
