package edu.zju.bme.tumorboard.controller;

/**
 * @author Meng.ZiZhong
 * @date 2021/2/4
 */

import edu.zju.bme.tumorboard.entity.Patient;
import edu.zju.bme.tumorboard.service.PatientService;
import edu.zju.bme.tumorboard.utils.RestResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@Slf4j
@RestController
@RequestMapping("/patient")
@CrossOrigin
public class PatientController {
    @Autowired
    PatientService patientService;

    @GetMapping("getAll")
    @ApiOperation(value = "获取所有病人")
    public RestResult getAll() {
        return RestResult.ok(patientService.getAll());
    }

    @GetMapping("getById")
    @ApiOperation(value = "根据病人id获取病人")
    @ApiImplicitParam(name = "patientId", value = "病人ID", required = true, dataType = "String")
    public RestResult getById(@RequestParam String patientId) {
        return RestResult.ok(patientService.selectByPrimaryKey(patientId));
    }

    @PostMapping("add")
    @ApiOperation(value = "添加病人")
    @ApiImplicitParam(name = "patient", value = "病人信息", required = true, dataType = "病人实体类")
    public RestResult add(@RequestBody Patient patient) {
        return RestResult.ok(patientService.insertSelective(patient));
    }

    @PostMapping("delete")
    @ApiOperation(value = "删除病人")
    @ApiImplicitParam(name = "patientId", value = "病人ID", required = true, dataType = "String")
    public RestResult delete(@RequestBody String patientId) {
        return RestResult.ok(patientService.deleteByPrimaryKey(patientId));
    }

    @PostMapping("update")
    @ApiOperation(value = "更新病人")
    @ApiImplicitParam(name = "patient", value = "病人信息", required = true, dataType = "病人实体类")
    public RestResult update(@RequestBody Patient patient) {
        return RestResult.ok(patientService.updateByPrimaryKeySelective(patient));
    }

    @GetMapping("getPatientImagReportInfo")
    @ApiOperation(value = "根据病人标识符获取病人检查报告信息")
    @ApiImplicitParam(name = "patientIdentifier", value = "病人标识符", required = true, dataType = "String")
    public RestResult getPatientImagReportInfo(@RequestParam String patientIdentifier) {
        return RestResult.ok(patientService.getPatientImagReportInfo(patientIdentifier));
    }

    @GetMapping("getCdrPatientBasicInfo")
    @ApiOperation(value = "根据病人标识符获取新增病人基本信息")
    @ApiImplicitParam(name = "patientIdentifier", value = "病人标识符", required = true, dataType = "String")
    public RestResult getPatientBasicInfo(@RequestParam String patientIdentifier) {
        return RestResult.ok(patientService.getCdrPatientBasicInfo(patientIdentifier));
    }
}
