package edu.zju.bme.tumorboard.controller;

/**
 * @author Meng.ZiZhong
 * @date 2021/2/4
 */

import edu.zju.bme.tumorboard.entity.PatientMeetingRecord;
import edu.zju.bme.tumorboard.service.PatientMeetingRecordService;
import edu.zju.bme.tumorboard.utils.RestResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@Slf4j
@RestController
@RequestMapping("/patientMeetingRecord")
@CrossOrigin
public class PatientMeetingRecordController {
    @Autowired
    PatientMeetingRecordService patientMeetingRecordService;

    @GetMapping("getByPatientId")
    @ApiOperation(value = "根据病人id获取病人所有会议记录")
    @ApiImplicitParam(name = "patientId", value = "病人ID", required = true, dataType = "String")
    public RestResult getByPatientId(@RequestParam String patientId) {
        return RestResult.ok(patientMeetingRecordService.getRecordListByPatientId(patientId));
    }

    @PostMapping("add")
    @ApiOperation(value = "添加病人会议记录")
    @ApiImplicitParam(name = "patientMeetingRecord", value = "病人会议记录信息", required = true, dataType = "病人会议记录实体类")
    public RestResult add(@RequestBody PatientMeetingRecord patientMeetingRecord) {
        return RestResult.ok(patientMeetingRecordService.insert(patientMeetingRecord));
    }

    @PostMapping("delete")
    @ApiOperation(value = "删除病人会议记录")
    @ApiImplicitParam(name = "recordId", value = "病人会议记录ID", required = true, dataType = "String")
    public RestResult delete(@RequestBody String recordId) {
        return RestResult.ok(patientMeetingRecordService.deleteByPrimaryKey(recordId));
    }

    @PostMapping("update")
    @ApiOperation(value = "更新病人会议记录")
    @ApiImplicitParam(name = "patientMeetingRecord", value = "病人会议记录信息", required = true, dataType = "病人会议记录实体类")
    public RestResult update(@RequestBody PatientMeetingRecord patientMeetingRecord) {
        return RestResult.ok(patientMeetingRecordService.updateByPrimaryKey(patientMeetingRecord));
    }
}
