package edu.zju.bme.tumorboard.mapper.manage;

/**
 * @author Meng.ZiZhong
 * @date 2021/2/4
 */

import edu.zju.bme.tumorboard.entity.ClinicalTestData;

import edu.zju.bme.tumorboard.entity.other.ClinicalTestDataFilterInfo;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface ClinicalTestDataMapper {

    /**
     * 根据筛选信息获取临床试验信息集合
     *
     * @param clinicalTestDataFilterInfo 临床试验信息筛选条件对象
     * @return List<ClinicalTestData> 临床试验信息集合
     */
    List<ClinicalTestData> getByFilterInfo(ClinicalTestDataFilterInfo clinicalTestDataFilterInfo);

    /**
     * 获取全部的临床试验信息
     *
     * @param
     * @return List<ClinicalTestData> 临床试验信息集合
     */
    List<ClinicalTestData> getAll();

    /**
     * 根据临床试验信息ID删除临床试验信息
     *
     * @param clinicalTestDataFilterInfo 临床试验信息id
     * @return
     */
    int deleteByPrimaryKey(String nctId);

    /**
     * 根据临床试验信息对象更新更新临床试验信息
     *
     * @param clinicalTestData 临床试验信息对象
     * @return
     */
    int updateByPrimaryKey(ClinicalTestData clinicalTestData);

    /**
     * 获取所有不同的国家名称
     *
     * @return List<String> 国家名称集合
     */
    List<String> getAllCountry();

    /**
     * 获取所有不同的状态
     *
     * @return List<String> 状态集合
     */
    List<String> getAllStatus();

    /**
     * 得到所有变异基因信息
     *
     * @return
     */
    List<String> getAllVariationGene();

    /**
     * 得到所有变异类型信息
     *
     * @return
     */
    List<String> getAllVariationType();

    /**
     * 得到所有变异位置信息
     *
     * @return
     */
    List<String> getAllVariationPosition();

    /**
     * 得到所有氨基酸变化信息
     *
     * @return
     */
    List<String> getAllVariationWnm();
}