package edu.zju.bme.tumorboard.mapper.manage;

/**
 * @author Meng.ZiZhong
 * @date 2021/3/29
 */

import com.github.pagehelper.PageInfo;
import edu.zju.bme.tumorboard.entity.ClinicalTestData;
import edu.zju.bme.tumorboard.entity.GeneGermlineVariant;
import edu.zju.bme.tumorboard.entity.GeneMutationInfo;
import edu.zju.bme.tumorboard.entity.other.ClinicalTestDataFilterInfo;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface GeneMutationMapper {

    /**
     * 获取全部基因变异信息集合
     *
     *
     * @return List<GeneMutationInfo> 基因变异信息集合
     */
    List<GeneMutationInfo> getAll();
    /**
     * 根据基因名称集合获取基因变异信息集合
     *
     * @param geneNames 基因名称集合
     * @return List<GeneMutationInfo> 基因变异信息集合
     */
    List<GeneMutationInfo> getByGene(List<String> geneNames);


    /**
     * 根据药品名称获取基因变异信息集合
     *
     * @param targetedDrugEn 药品名称
     * @return List<GeneMutationInfo> 基因变异信息集合
     */
    List<GeneMutationInfo> getByDrug(String targetedDrugEn);

    /**
     * 根据临床试验信息ID删除临床试验信息
     *
     * @param clinicalTestDataFilterInfo 临床试验信息id
     * @return
     */
    int deleteByPrimaryKey(String nctId);

    /**
     * 根据临床试验信息对象更新更新临床试验信息
     *
     * @param clinicalTestData 临床试验信息对象
     * @return
     */
    int updateByPrimaryKey(ClinicalTestData clinicalTestData);

    /**
     * 获取体细胞突变与靶向药物知识库所有不同的基因名称
     *
     *
     * @return List<String> 基因名称集合
     */
    List<String> getAllGeneName();

    /**
     * 获取体细胞突变与靶向药物知识库所有不同的药物名称
     *
     * @return List<String> 药物名称集合
     */
    List<String> getAllDrugName();

    /**
     * 获取胚系变异与化疗药物知识库的变体一
     *
     * @return List<String> 变体集合
     */
    List<String> getVariantOne(@Param("variantTwo")String variantTwo, @Param("phenotypeList")List<String> phenotypeList);

    /**
     * 获取胚系变异与化疗药物知识库的变体二
     *
     * @return List<String> 变体集合
     */
    List<String> getVariantTwo(@Param("variantOne")String variantOne, @Param("phenotypeList")List<String> phenotypeList);

    /**
     * 获取胚系变异与化疗药物知识库所有不同的基因名称
     *
     * @return List<String> 基因名称集合
     */
    List<String> getGeneNameInVariant(@Param("drugNameEn")String drugNameEn, @Param("phenotypeList")List<String> phenotypeList);

    /**
     * 获取胚系变异与化疗药物知识库的药物名称
     *
     * @return List<String> 药物名称集合
     */
    List<String> getDrugNameInVariant(@Param("gene")String gene, @Param("phenotypeList")List<String> phenotypeList);

    /**
     * 获取胚系变异与化疗药物知识库基因变异解读信息
     *
     * @return GeneGermlineVariant 基因变异解读信息
     */
    List<GeneGermlineVariant> getVariantUnscrambleInfo(@Param("geneGermlineVariant")GeneGermlineVariant geneGermlineVariant, @Param("phenotypeList")List<String> phenotypeList);

    /**
     * 获取胚系变异与化疗药物知识库的表型
     *
     * @return List<String> 药物名称集合
     */
    List<String> getPhenotypeByGeneGermlineVariant(GeneGermlineVariant geneGermlineVariant);

    /**
     * 根据基因检测信息获取基因突变信息
     *
     * @param geneTestInfoList 基因检测信息集合
     * @return List<GeneMutationInfo> 基因变异信息集合
     */
    List<GeneMutationInfo> getGeneMutationByGeneTestInfo(List<GeneMutationInfo> geneTestInfoList);

    /**
     * 根据基因突变信息获取药物名称集合
     *
     * @param geneTestInfoList 基因突变信息
     * @return List<String> 药物名称集合
     */
    List<String> getGeneMutationDrugList(GeneMutationInfo geneMutationInfo);
}