package edu.zju.bme.tumorboard.service;

/**
 * @author Meng.ZiZhong
 * @date 2021/2/4
 */

import com.github.pagehelper.PageInfo;
import edu.zju.bme.tumorboard.entity.ClinicalTestData;
import edu.zju.bme.tumorboard.entity.HospitalClinicalTestData;
import edu.zju.bme.tumorboard.entity.other.ClinicalTestDataFilterInfo;
import edu.zju.bme.tumorboard.entity.other.ClinicalTestDataSelectInfo;

import java.util.List;


public interface ClinicalTestDataService {

    /**
     * 根据筛选信息获取临床试验信息集合
     *
     * @param clinicalTestDataFilterInfo 临床试验信息筛选条件对象
     * @return PageInfo<ClinicalTestData> 临床试验信息分页集合
     */
    PageInfo<ClinicalTestData> getByFilterInfo(ClinicalTestDataFilterInfo clinicalTestDataFilterInfo);

    /**
     * 根据筛选条件得到院内临床试验数据
     *
     * @param testData
     * @param pageIndex
     * @param limitNumber
     * @return
     */
    List<HospitalClinicalTestData> getHospitalTestByFilterInfo(HospitalClinicalTestData testData,
                                                                   Integer pageIndex, Integer limitNumber);

    /**
     * 得到符合条件的院内临床试验数量
     * @param testData
     * @return
     */
    Integer countHospitalTestByFilterInfo(HospitalClinicalTestData testData);

    /**
     * 根据临床试验信息ID删除临床试验信息
     *
     * @param nctId 临床试验信息id
     * @return
     */
    int deleteByPrimaryKey(String nctId);

    /**
     * 根据临床试验信息对象更新临床试验信息
     *
     * @param clinicalTestData 临床试验信息对象
     * @return
     */
    int updateByPrimaryKey(ClinicalTestData clinicalTestData);

    /**
     * 获取所有国家和状态名称
     *
     * @param
     * @return ClinicalTestDataSelectInfo 临床试验筛选信息对象
     */
    ClinicalTestDataSelectInfo getSelectInfo();
}
