package edu.zju.bme.tumorboard.service;

/**
 * @author Meng.ZiZhong
 * @date 2021/3/29
 */


import com.github.pagehelper.PageInfo;
import edu.zju.bme.tumorboard.entity.GeneGermlineVariant;
import edu.zju.bme.tumorboard.entity.GeneMutationInfo;
import edu.zju.bme.tumorboard.entity.other.ClinicalTestDataFilterInfo;

import java.util.List;
import java.util.Map;


public interface GeneMutationService {

    /**
     * 获取全部的基因变异信息
     *
     *
     * @return List<GeneMutationInfo> 基因变异信息集合
     */
    PageInfo<GeneMutationInfo> getAll(Integer pageIndex);

    /**
     * 根据基因名称集合获取基因变异信息集合
     *
     * @param geneNames 基因名称集合
     * @return List<GeneMutationInfo> 基因变异信息集合
     */
    PageInfo<GeneMutationInfo> getByGene(List<String> geneNames, Integer pageIndex);

    /**
     * 根据药品名称获取基因变异信息集合
     *
     * @param targetedDrugEn 药品名称
     * @return List<GeneMutationInfo> 基因变异信息集合
     */
    PageInfo<GeneMutationInfo> getByDrug(String targetedDrugEn, Integer pageIndex);

    /**
     * 获取体细胞突变与靶向药物知识库所有基因和药物名称
     *
     * @param
     * @return Map<String, List<String>> 基因和药物名称
     */
    Map<String, List<String>> getSelectInfo();

    /**
     * 获取胚系变异与化疗药物知识库所有基因，药物名称和两个单倍型
     *
     * @param
     * @return Map<String, List<String>> 所有基因和药物名称和两个单倍型
     */
    Map<String, List<String>> getVariantSelectInfo(GeneGermlineVariant geneGermlineVariant);

    /**
     * 获取胚系变异与化疗药物知识库基因变异解读信息
     *
     * @return GeneGermlineVariant 基因变异解读信息
     */
    PageInfo<GeneGermlineVariant> getVariantUnscrambleInfo(GeneGermlineVariant geneGermlineVariant);

    /**
     * 根据基因检测信息获取靶向药物信息
     *
     * @param geneNames 基因检测信息集合
     * @return List<GeneMutationInfo> 基因变异信息集合
     */
    PageInfo<GeneMutationInfo> getGeneMutationByGeneTestInfo(List<GeneMutationInfo> geneTestInfoList, Integer pageIndex);

    /**
     * 根据基因检测信息获取化疗药物信息
     *
     * @param geneNames 基因检测信息集合
     * @return List<GeneMutationInfo> 基因变异信息集合
     */
    Map<String, List<GeneGermlineVariant>> getGeneGermlineVariantByGeneTestInfo(List<GeneGermlineVariant> geneGermlineVariantList);
}
