package edu.zju.bme.tumorboard.service;

/**
 * @author Meng.ZiZhong
 * @date 2021/2/4
 */

import edu.zju.bme.tumorboard.entity.Patient;
import edu.zju.bme.tumorboard.entity.other.PatientImagReportInfo;

import java.util.List;
import java.util.Map;

public interface PatientService {

    /**
     * 获取所有病人
     *
     * @return  List<Patient> 病人对象集合
     */
    List<Patient> getAll();

    /**
     * 根据病人ID删除病人
     * @param patientId 病人ID
     * @return  List<Patient> 病人信息集合
     */
    int deleteByPrimaryKey(String patientId);

    /**
     * 添加病人
     * @param record 病人对象
     * @return
     */
    int insertSelective(Patient record);

    /**
     * 根据病人ID获取病人
     * @param patientId 病人ID
     * @return patient 病人对象
     */
    Patient selectByPrimaryKey(String patientId);

    /**
     * 根据病人对象更新病人
     * @param patient 病人对象
     * @return
     */
    int updateByPrimaryKeySelective(Patient record);

    /**
     * 根据病人标识符获取病人检查报告信息
     * @param patientIdentifier 病人标识符
     * @return PatientImagInfo 病人检查报告信息
     */
    List<PatientImagReportInfo> getPatientImagReportInfo(String patientIdentifier);

    /**
     * 根据病人标识符获取病人基本信息
     * @param patientIdentifier 病人标识符
     * @return Map 病人基本信息
     */
    Map getCdrPatientBasicInfo(String patientIdentifier);
}
