package edu.zju.bme.tumorboard.service.impl;

/**
 * @author Meng.ZiZhong
 * @date 2021/2/4
 */

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import edu.zju.bme.tumorboard.entity.ClinicalTestData;
import edu.zju.bme.tumorboard.entity.HospitalClinicalTestData;
import edu.zju.bme.tumorboard.entity.other.ClinicalTestDataFilterInfo;
import edu.zju.bme.tumorboard.entity.other.ClinicalTestDataSelectInfo;
import edu.zju.bme.tumorboard.mapper.hospital.HospitalClinicalTestMapper;
import edu.zju.bme.tumorboard.mapper.manage.ClinicalTestDataMapper;
import edu.zju.bme.tumorboard.service.ClinicalTestDataService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
@Slf4j
public class ClinicalTestDataServiceImpl implements ClinicalTestDataService {
    @Autowired
    private ClinicalTestDataMapper clinicalTestDataMapper;

    @Autowired
    private HospitalClinicalTestMapper hospitalClinicalTestMapper;

    @Override
    public PageInfo<ClinicalTestData> getByFilterInfo(ClinicalTestDataFilterInfo clinicalTestDataFilterInfo) {
        if (clinicalTestDataFilterInfo.getLimitNumber() != null) {
            PageHelper.startPage(clinicalTestDataFilterInfo.getPageIndex(), clinicalTestDataFilterInfo.getLimitNumber());
        } else {
            PageHelper.startPage(clinicalTestDataFilterInfo.getPageIndex(), 5);
        }
        List<ClinicalTestData> clinicalTestDataList = clinicalTestDataMapper.getByFilterInfo(clinicalTestDataFilterInfo);
        return new PageInfo<>(clinicalTestDataList);
    }

    @Override
    public List<HospitalClinicalTestData> getHospitalTestByFilterInfo(HospitalClinicalTestData testData,
                                                                      Integer pageIndex, Integer limitNumber) {
        if (limitNumber == null) {
            limitNumber = 5;
        }
        Integer pageStart = (pageIndex - 1) * limitNumber;
        Integer pageEnd = (pageIndex) * limitNumber;
        List<HospitalClinicalTestData> testDataList = hospitalClinicalTestMapper.getByFilterInfo(testData, pageStart, pageEnd);
        return testDataList;
    }

    @Override
    public Integer countHospitalTestByFilterInfo(HospitalClinicalTestData testData) {
        return hospitalClinicalTestMapper.countByFilterInfo(testData);
    }

    @Override
    public int deleteByPrimaryKey(String nctId) {
        return clinicalTestDataMapper.deleteByPrimaryKey(nctId);
    }

    @Override
    public int updateByPrimaryKey(ClinicalTestData record) {
        return clinicalTestDataMapper.updateByPrimaryKey(record);
    }

    @Override
    public ClinicalTestDataSelectInfo getSelectInfo() {
        ClinicalTestDataSelectInfo clinicalTestDataSelectInfo = new ClinicalTestDataSelectInfo();
        clinicalTestDataSelectInfo.setCountry(clinicalTestDataMapper.getAllCountry());
        clinicalTestDataSelectInfo.setStatus(clinicalTestDataMapper.getAllStatus());
        // 院内临床试验科室列表
        clinicalTestDataSelectInfo.setHospitalDeptList(hospitalClinicalTestMapper.getAllDept());
        // 院外临床试验变异信息
        clinicalTestDataSelectInfo.setGeneList(clinicalTestDataMapper.getAllVariationGene());
        clinicalTestDataSelectInfo.setVariationTypeList(clinicalTestDataMapper.getAllVariationType());
        clinicalTestDataSelectInfo.setVariationPositionList(clinicalTestDataMapper.getAllVariationPosition());
        clinicalTestDataSelectInfo.setVariationWnmList(clinicalTestDataMapper.getAllVariationWnm());
        return clinicalTestDataSelectInfo;
    }
}
