package edu.zju.bme.tumorboard.service.impl;

/**
 * @author Meng.ZiZhong
 * @date 2021/3/29
 */

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import edu.zju.bme.tumorboard.entity.GeneGermlineVariant;
import edu.zju.bme.tumorboard.entity.GeneMutationInfo;
import edu.zju.bme.tumorboard.mapper.manage.GeneMutationMapper;
import edu.zju.bme.tumorboard.service.GeneMutationService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
@Slf4j
public class GeneMutationServiceImpl implements GeneMutationService {
    @Autowired
    private GeneMutationMapper geneMutationMapper;

    @Override
    public PageInfo<GeneMutationInfo> getAll(Integer pageIndex) {
        if (pageIndex == null) {
            pageIndex = 1;
        }
        PageHelper.startPage(pageIndex, 10);
        List<GeneMutationInfo> geneMutationInfoList = geneMutationMapper.getAll();
        return new PageInfo<>(geneMutationInfoList);
    }

    @Override
    public PageInfo<GeneMutationInfo> getByGene(List<String> geneNames,Integer pageIndex) {
        if (pageIndex == null) {
            pageIndex = 1;
        }
        PageHelper.startPage(pageIndex, 10);
        List<GeneMutationInfo> geneMutationInfoList = geneMutationMapper.getByGene(geneNames);
//        List<String> drugNameList = geneMutationMapper.getAllDrugName();
//        Map<String,List<String>> drugMap = new HashMap<>();
//        for (String drugName : drugNameList) {
//            List<String> geneList = new ArrayList<>();
//            drugMap.put(drugName, geneList);
//        }
//        geneMutationInfoList.stream().forEach(item -> drugMap.get(item.getTargetedDrugCh()));
        return new PageInfo<>(geneMutationInfoList);
    }

    @Override
    public PageInfo<GeneMutationInfo> getByDrug(String targetedDrugEn, Integer pageIndex) {
        if (pageIndex == null) {
            pageIndex = 1;
        }
        PageHelper.startPage(pageIndex, 10);
        List<GeneMutationInfo> geneMutationInfoList = geneMutationMapper.getByDrug(targetedDrugEn);
        return new PageInfo<>(geneMutationInfoList);
    }

    @Override
    public Map<String, List<String>> getSelectInfo() {
        Map<String, List<String>> selectInfo = new HashMap<>();
        selectInfo.put("gene",geneMutationMapper.getAllGeneName());
        selectInfo.put("drug",geneMutationMapper.getAllDrugName());
        return selectInfo;
    }

    @Override
    public Map<String, List<String>> getVariantSelectInfo(GeneGermlineVariant geneGermlineVariant) {
        Map<String, List<String>> selectInfo = new HashMap<>();
        List<String> phenotypeList = geneMutationMapper.getPhenotypeByGeneGermlineVariant(geneGermlineVariant);
        selectInfo.put("gene",geneMutationMapper.getGeneNameInVariant(geneGermlineVariant.getDrugNameEn(), phenotypeList));
        selectInfo.put("drug",geneMutationMapper.getDrugNameInVariant(geneGermlineVariant.getGene(), phenotypeList));
        selectInfo.put("variantOne",geneMutationMapper.getVariantOne(geneGermlineVariant.getVariantTwo(), phenotypeList));
        selectInfo.put("variantTwo",geneMutationMapper.getVariantTwo(geneGermlineVariant.getVariantOne(), phenotypeList));
        return selectInfo;
    }

    @Override
    public PageInfo<GeneGermlineVariant> getVariantUnscrambleInfo(GeneGermlineVariant geneGermlineVariant) {
        if (geneGermlineVariant.getPageIndex() == null) {
            geneGermlineVariant.setPageIndex(1);
        }
        List<String> phenotypeList = geneMutationMapper.getPhenotypeByGeneGermlineVariant(geneGermlineVariant);
        PageHelper.startPage(geneGermlineVariant.getPageIndex(), 3);
        List<GeneGermlineVariant> geneGermlineVariantInfoList = geneMutationMapper.getVariantUnscrambleInfo(geneGermlineVariant, phenotypeList);
        return new PageInfo<>(geneGermlineVariantInfoList);
    }

    @Override
    public PageInfo<GeneMutationInfo> getGeneMutationByGeneTestInfo(List<GeneMutationInfo> geneTestInfoList, Integer pageIndex) {
        if (pageIndex == null) {
            pageIndex = 1;
        }
        PageHelper.startPage(pageIndex, 5);
        List<GeneMutationInfo> geneMutationInfoList = geneMutationMapper.getGeneMutationByGeneTestInfo(geneTestInfoList);
        for (GeneMutationInfo geneMutationInfo : geneMutationInfoList) {
            geneMutationInfo.setDrugList(geneMutationMapper.getGeneMutationDrugList(geneMutationInfo));
        }
        return new PageInfo<>(geneMutationInfoList);
    }

    @Override
    public Map<String, List<GeneGermlineVariant>> getGeneGermlineVariantByGeneTestInfo(List<GeneGermlineVariant> geneGermlineVariantList) {
        Map<String, List<GeneGermlineVariant>> geneGermlineVariantMap = new HashMap<>();
        for (GeneGermlineVariant geneGermlineVariant: geneGermlineVariantList) {
            geneGermlineVariantMap.computeIfAbsent(geneGermlineVariant.getGene(), value -> new ArrayList<>());
            List<String> phenotypeList = geneMutationMapper.getPhenotypeByGeneGermlineVariant(geneGermlineVariant);
            if (phenotypeList.size() > 0) {
                geneGermlineVariantMap.get(geneGermlineVariant.getGene()).addAll(geneMutationMapper.getVariantUnscrambleInfo(geneGermlineVariant, phenotypeList));
            }
        }
        return geneGermlineVariantMap;
    }
}
