package edu.zju.bme.tumorboard.service.impl;

/**
 * @author Meng.ZiZhong
 * @date 2021/2/4
 */

import edu.zju.bme.tumorboard.entity.Patient;
import edu.zju.bme.tumorboard.entity.other.PatientImagReportInfo;
import edu.zju.bme.tumorboard.mapper.cdr.PatientBasicInfoMapper;
import edu.zju.bme.tumorboard.mapper.manage.PatientMapper;
import edu.zju.bme.tumorboard.service.PatientService;
import edu.zju.bme.tumorboard.utils.ErrorWithMessage;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

@Service
@Slf4j
public class PatientServiceImpl implements PatientService {
    @Autowired
    private PatientMapper patientMapper;
    @Autowired
    private PatientBasicInfoMapper patientBasicInfoMapper;

    @Override
    public List<Patient> getAll() {
        return patientMapper.getAll();
    }

    @Override
    public int deleteByPrimaryKey(String patientId) {
        return patientMapper.deleteByPrimaryKey(patientId);
    }

    @Override
    public int insertSelective(Patient record) {
        record.setPatientId(UUID.randomUUID().toString());
        judgeRepeatPatient(record);
        record.setCreateDate(new Date());
        return patientMapper.insertSelective(record);
    }

    @Override
    public Patient selectByPrimaryKey(String patientId) {
        return patientMapper.selectByPrimaryKey(patientId);
    }

    @Override
    public int updateByPrimaryKeySelective(Patient record) {
        judgeRepeatPatient(record);
        record.setUpdateDate(new Date());
        return patientMapper.updateByPrimaryKeySelective(record);
    }

    @Override
    public List<PatientImagReportInfo> getPatientImagReportInfo(String patientIdentifier) {
        return patientBasicInfoMapper.getPatientImagReportInfo(patientIdentifier);
    }

    @Override
    public Map getCdrPatientBasicInfo(String patientIdentifier) {
        Map basicInfo;
        String encoutnIdenfier = patientBasicInfoMapper.getLatestAdmissionEncounterIdetifier(patientIdentifier);
        if (encoutnIdenfier != null) {
            basicInfo = patientBasicInfoMapper.getCdrPatientBasicInfo(encoutnIdenfier, patientIdentifier);
            return basicInfo;
        }
        return null;
    }

    private void judgeRepeatPatient(Patient patient) {
        Patient judgePatient = patientMapper.getPatientByPatientIdentifier(patient.getPatientIdentifier());
        if (judgePatient != null && !judgePatient.getPatientId().equals(patient.getPatientId())) {
            throw new ErrorWithMessage("病人标识符重复");
        }
    }
}
