import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';

import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';
import { NZ_I18N } from 'ng-zorro-antd/i18n';
import { zh_CN } from 'ng-zorro-antd/i18n';
import { registerLocaleData } from '@angular/common';
import zh from '@angular/common/locales/zh';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { HTTP_INTERCEPTORS, HttpClientModule } from '@angular/common/http';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';

import { NzLayoutModule } from 'ng-zorro-antd/layout';
import { NzMenuModule } from 'ng-zorro-antd/menu';
import { NzDropDownModule } from 'ng-zorro-antd/dropdown';
import { NzAvatarModule } from 'ng-zorro-antd/avatar';
import { NzButtonModule } from 'ng-zorro-antd/button';
import { IconDefinition } from '@ant-design/icons-angular';
import { NzBreadCrumbModule } from 'ng-zorro-antd/breadcrumb';
import { NzGridModule } from 'ng-zorro-antd/grid';
import { NzIconModule } from 'ng-zorro-antd/icon';
import { NzTypographyModule } from 'ng-zorro-antd/typography';
import { NzCardModule } from 'ng-zorro-antd/card';
import { NzDividerModule } from 'ng-zorro-antd/divider';
import { NzDescriptionsModule } from 'ng-zorro-antd/descriptions';
import { NzToolTipModule } from 'ng-zorro-antd/tooltip';
import { NzStatisticModule } from 'ng-zorro-antd/statistic';
import { NzTabsModule } from 'ng-zorro-antd/tabs';
import { NzSelectModule } from 'ng-zorro-antd/select';
import { NzTagModule } from 'ng-zorro-antd/tag';
import { NzListModule } from 'ng-zorro-antd/list';
import { NzModalModule } from 'ng-zorro-antd/modal';
// 引入你需要的图标，比如你需要 fill 主题的 AccountBook Alert 和 outline 主题的 Alert，推荐 ✔️
import {
    UserOutline,
    SettingOutline,
    LogoutOutline,
    SolutionOutline,
    RollbackOutline,
    FormOutline,
    CloudSyncOutline,
    ArrowUpOutline,
    FullscreenOutline,
    FullscreenExitOutline,
    UpOutline,
    DownOutline
} from '@ant-design/icons-angular/icons';

const icons: IconDefinition[] = [UserOutline, SettingOutline, LogoutOutline, SolutionOutline, RollbackOutline, FormOutline,
    CloudSyncOutline, ArrowUpOutline, FullscreenOutline, FullscreenExitOutline, UpOutline, DownOutline];

import { DirectiveModule } from './directive/directive.module';
import { CoreModule } from './core/core.module';
import { PipeModule } from './pipe/pipe.module';

import { PatientListComponent } from './patient-list/patient-list.component';
import { DataReadyComponent } from './data-ready/data-ready.component';
import { PatientViewComponent } from './patient-view/patient-view.component';
import { DiagnosisTreatComponent } from './patient-view/diagnosis-treat/diagnosis-treat.component';
import { StageComponent } from './patient-view/stage/stage.component';
import { PrognosisAssessComponent } from './patient-view/prognosis-assess/prognosis-assess.component';
import { ClinicTestRecommendComponent } from './patient-view/clinic-test-recommend/clinic-test-recommend.component';
import { GeneUnscrambleComponent } from './patient-view/gene-unscramble/gene-unscramble.component';
import { CdssReadyComponent } from './data-ready/cdss-ready/cdss-ready.component';
import { BackendApiInterceptor } from "./core/backend-api-intercepter";
import { NzFormModule } from "ng-zorro-antd/form";
import { NzInputModule } from "ng-zorro-antd/input";
import { NzInputNumberModule } from "ng-zorro-antd/input-number";
import { NzDatePickerModule } from "ng-zorro-antd/date-picker";
import { NzPopconfirmModule } from "ng-zorro-antd/popconfirm";
import { NzDrawerModule } from "ng-zorro-antd/drawer";
import { NzPaginationModule } from "ng-zorro-antd/pagination";
import { ClinicalGuidelineComponent } from './patient-view/clinical-guideline/clinical-guideline.component';
import { NzTimelineModule } from "ng-zorro-antd/timeline";
import { NgxEchartsModule } from 'ngx-echarts';
import { NzSpinModule } from 'ng-zorro-antd/spin';
import { NzSwitchModule } from 'ng-zorro-antd/switch';
import { NzEmptyModule } from 'ng-zorro-antd/empty';
import { PercentPipe, DatePipe } from '@angular/common';
import { NzTableModule } from "ng-zorro-antd/table";
import { RepoSearchComponent } from './patient-view/gene-unscramble/repo-search/repo-search.component';
import { NzCollapseModule } from "ng-zorro-antd/collapse";
import { TreatmentHistoryComponent } from './patient-view/diagnosis-treat/treatment-history/treatment-history.component';
import { PathologyComponent } from './patient-view/diagnosis-treat/pathology/pathology.component';
import { MajorComplicationsComponent } from './patient-view/diagnosis-treat/major-complications/major-complications.component';
import { InspectComponent } from './patient-view/diagnosis-treat/inspect/inspect.component';
import { MedicalHistoryComponent } from './patient-view/diagnosis-treat/medical-history/medical-history.component';
import { NzPopoverModule } from "ng-zorro-antd/popover";
import { TreatmentHistoryPptComponent } from './patient-view/diagnosis-treat/treatment-history-ppt/treatment-history-ppt.component';
import { NzStepsModule } from "ng-zorro-antd/steps";
import { NzBadgeModule } from "ng-zorro-antd/badge";
import { NzBackTopModule } from 'ng-zorro-antd/back-top';
import { NzAffixModule } from 'ng-zorro-antd/affix';

registerLocaleData(zh);

@NgModule({
    declarations: [
        AppComponent,
        PatientListComponent,
        DataReadyComponent,
        PatientViewComponent,
        DiagnosisTreatComponent,
        StageComponent,
        PrognosisAssessComponent,
        ClinicTestRecommendComponent,
        GeneUnscrambleComponent,
        CdssReadyComponent,
        ClinicalGuidelineComponent,
        RepoSearchComponent,
        TreatmentHistoryComponent,
        PathologyComponent,
        MajorComplicationsComponent,
        InspectComponent,
        MedicalHistoryComponent,
        TreatmentHistoryPptComponent
    ],
    imports: [
        BrowserModule,
        AppRoutingModule,
        FormsModule,
        HttpClientModule,
        BrowserAnimationsModule,
        DirectiveModule,
        CoreModule,
        PipeModule,

        NzLayoutModule,
        NzMenuModule,
        NzDropDownModule,
        NzAvatarModule,
        NzButtonModule,
        NzGridModule,
        NzBreadCrumbModule,
        NzIconModule.forRoot(icons),
        NzTypographyModule,
        NzCardModule,
        NzDividerModule,
        NzDescriptionsModule,
        NzToolTipModule,
        NzStatisticModule,
        NzTabsModule,
        NzSelectModule,
        NzTagModule,
        NzListModule,
        NzModalModule,
        NzFormModule,
        NzInputModule,
        NzInputNumberModule,
        ReactiveFormsModule,
        NzDatePickerModule,
        NzPopconfirmModule,
        NzDrawerModule,
        NzPaginationModule,
        NzTimelineModule,
        NgxEchartsModule.forRoot({
            echarts: () => import('echarts'),
        }),
        NzSpinModule,
        NzSwitchModule,
        NzEmptyModule,
        NzTableModule,
        NzCollapseModule,
        NzPopoverModule,
        NzStepsModule,
        NzBadgeModule,
        NzBackTopModule,
        NzAffixModule
    ],
    providers: [{ provide: NZ_I18N, useValue: zh_CN },
        PercentPipe, DatePipe,
    { provide: HTTP_INTERCEPTORS, useClass: BackendApiInterceptor, multi: true },],
    bootstrap: [AppComponent]
})
export class AppModule {
}
