import { Injectable } from '@angular/core';
import { HttpErrorResponse, HttpEvent, HttpHandler, HttpInterceptor, HttpRequest, HttpResponse } from '@angular/common/http';
import { Observable, throwError } from 'rxjs';
import { map, catchError } from "rxjs/operators";
import {NzMessageService} from "ng-zorro-antd/message";
import {NzModalService} from "ng-zorro-antd/modal";
import {URLService} from "./others/url.service";
import {str2hex} from "./others/login.service";



@Injectable()
export class BackendApiInterceptor implements HttpInterceptor {
    constructor(private _message: NzMessageService, private _modal: NzModalService, private urlService: URLService) {}

    intercept(req: HttpRequest<any>, next: HttpHandler): Observable<HttpEvent<any>> {
        let headers = {
            'Content-Type': '',
            '_sessionId': '',
            'username': '',
        };
        if (!(req.body instanceof FormData)) {
            headers['Content-Type'] = 'application/json';
        }
        let sessionId = sessionStorage.getItem('_sessionId');
        if (sessionId) {
            headers['_sessionId'] = sessionId;
            headers['username'] = sessionStorage.getItem('user_name')!;
        }
        return next!.handle(req.clone({ setHeaders: headers! })).pipe(map(ev => {
            let result = ev;
            let resultHttpEvent : any = ev;
            if (!(result instanceof HttpResponse)) {
                return result;
            }
            if (result.body == null) {
                // this._message.error('无法连接服务器');
                console.log('无法连接服务器');
                return;
            }

            if (result.ok && 'code' in result.body) {
                if (result.body.code != 'OK') {  // 全局显示错误信息，不再像以前一样每处调用接口的地方写显示逻辑
                    if (result.body.data) {
                        this.showSpecialErrors(result.body.message, result.body.data);
                    } else if (result.body.message) {
                        // this._message.error(result.body.message);
                        console.log(result.body.message);
                    } else {
                        // this._message.error('未知错误');
                        console.log('未知错误');
                    }
                    throw result.body.message;
                }
                return resultHttpEvent.clone({body: result.body.data});
            }
            return result;
        }), catchError((err) => {
            if (err instanceof HttpErrorResponse) {
                if (err.status == 0) {
                    // this._message.error('无法连接服务器');
                    console.log("无法连接服务器");
                } else if (err.status == 401) {
                    sessionStorage.clear();
                    window.location.href = this.urlService.loginUrl + '?target=' + str2hex(this.urlService.tumorBoardUrl + this.urlService.defaultRoute);
                } else if (400 <= err.status && err.status < 600) {
                    if (err.status == 500) {
                        console.log(err);
                        if (err.error && err.error.message) {
                            // this._message.error(err.error.message);
                            console.log(err.error.message);
                        } else {
                            // this._message.error("服务器内部错误");
                            console.log("服务器内部错误");
                        }
                    } else {
                        // this._message.error('服务器接口错误');
                        console.log("服务器接口错误");
                    }
                }
            }
            return throwError(err);
        }));
    }

    showSpecialErrors(message: String, data : any[]) {
        if (message == 'CONTROL_CHECK_RESULT') {
            let err = '以下控件含有错误：';
            err += data.map(i => `${i.control.nameZh}`).join('，');
            // this._message.error(err);
            console.log(err);
        } else {
            // this._message.error(message.toString());
            // console.error(data);
            console.log(data);
        }
    }
}
