import { Injectable } from '@angular/core';
import { Subject } from 'rxjs';
import { URLService } from "./url.service";
import { HttpClient } from "@angular/common/http";


export function str2hex(str: string) {
    if (str === "") {
        return "";
    }
    const arr: Array<string> = [];
    arr.push("0x");
    for (let i = 0; i < str.length; i++) {
        arr.push(str.charCodeAt(i).toString(16));
    }
    return arr.join('');
}


@Injectable({
    providedIn: 'root'
})
export class LoginService {
    public loggedIn: boolean = false;
    public logStatusSubject$ = new Subject<boolean>();

    constructor(private urlService: URLService, private httpClient: HttpClient) {
        let sessionId = sessionStorage.getItem('_sessionId');

        if (sessionId) {
            if (!this.isLoggedIn()) {
                this.setLoginState(true);
            }
        }
    }

    setupLogin() {
        this.setLoginState(true);
    }

    setLoginState(loggedIn: boolean) {
        this.loggedIn = loggedIn;
        this.logStatusSubject$.next(loggedIn);
    }

    isLoggedIn() {
        return this.loggedIn;
    }

    getUsername() {
        return sessionStorage.getItem('user_name');
    }

    logout() {
        let sessionId = sessionStorage.getItem('_sessionId');
        this.setLoginState(false);
        console.log('log out');
        sessionStorage.clear();
        localStorage.clear();
        this.httpClient.delete(this.urlService.URL_DELETE_LOGOUT + sessionId).subscribe(() => {
            window.location.href = (this.urlService.loginUrl.replace('login', 'logout') +
                '?target=' + str2hex(this.urlService.tumorBoardUrl + this.urlService.defaultRoute + '?source=logout'));
        });
    }
}
