import {Observable, Subject, throwError} from "rxjs";
import { Injectable } from '@angular/core';
import {HttpClient, HttpHeaders, HttpErrorResponse, HttpRequest} from '@angular/common/http';

import {catchError, map} from 'rxjs/operators';
import { NzModalService } from 'ng-zorro-antd/modal';
import {URLService} from "./url.service";
import {str2hex} from "./login.service";
import {Utils} from "../utils/utils.service";

@Injectable()
export class ResourceService {

    progress$ = new Subject<any>();
    constructor(
        private http: HttpClient,
        private utils: Utils,
        private urlService: URLService) { }

    get(url: string): Observable<Object> {
        var options = undefined;
        let sessionId: string = sessionStorage.getItem('_sessionId')!;
        if (!sessionId) {
            sessionId = localStorage.getItem('_sessionId')!;
            sessionStorage.setItem('_sessionId', sessionId);
            sessionStorage.setItem('user_name', localStorage.getItem('user_name')!);
            sessionStorage.setItem('user_id', localStorage.getItem('user_id')!);
        }
        if (sessionId) {
            let headers = new HttpHeaders({ '_sessionId': sessionId, 'username': sessionStorage.getItem('user_name')! });
            const projectId: string = sessionStorage.getItem('projectId')!;
            if (projectId) {
                headers = headers.append("projectId", projectId);
            }
            options = { headers: headers };
        }
        return this.http.get(url, options).pipe(map(res => { return res || {} }), catchError(this.handleError.bind(this)));
    }

    delete(url: string): Observable<Object> {
        var options = undefined;
        let sessionId: string = sessionStorage.getItem('_sessionId')!;
        if (!sessionId) {
            sessionId = localStorage.getItem('_sessionId')!;
            sessionStorage.setItem('_sessionId', sessionId);
            sessionStorage.setItem('user_name', localStorage.getItem('user_name')!);
            sessionStorage.setItem('user_id', localStorage.getItem('user_id')!);
        }
        if (sessionId) {
            let headers = new HttpHeaders({ '_sessionId': sessionId, 'username': sessionStorage.getItem('user_name')! });
            const projectId: string = sessionStorage.getItem('projectId')!;
            if (projectId) {
                headers = headers.append("projectId", projectId);
            }
            options = { headers: headers };
        }
        return this.http.delete(url, options).pipe(map(res => { return res || {} }), catchError(this.handleError.bind(this)));
    }

    post(url: string, body?: any): Observable<Object> {
        body = body || {};
        /** the  headers should be local variable */
        let headers = new HttpHeaders({ 'Content-type': 'application/json ; charset=utf-8 ' });
        let sessionId: string = sessionStorage.getItem('_sessionId')!;
        if (!sessionId) {
            sessionId = localStorage.getItem('_sessionId')!;
            sessionStorage.setItem('_sessionId', sessionId);
            sessionStorage.setItem('user_name', localStorage.getItem('user_name')!);
            sessionStorage.setItem('user_id', localStorage.getItem('user_id')!);
        }
        if (sessionId) {
            headers = headers.append('_sessionId', sessionId).append('username', sessionStorage.getItem('user_name')!);
            const projectId: string = sessionStorage.getItem('projectId')!;
            if (projectId) {
                headers = headers.append("projectId", projectId);
            }
        }
        let options = { headers: headers };
        return this.http.post(url, body, options).pipe(map(res => { console.log(res);
         return res !== null && res !== undefined ? res : {} }), catchError(this.handleError.bind(this)));
    }

    patch(url: string, body?: any): Observable<Object> {
        body = body || {};
        /** the  headers should be local variable */
        let headers = new HttpHeaders({ 'Content-type': 'application/json ; charset=utf-8 ' });
        let sessionId: string = sessionStorage.getItem('_sessionId')!;
        if (!sessionId) {
            sessionId = localStorage.getItem('_sessionId')!;
            sessionStorage.setItem('_sessionId', sessionId);
            sessionStorage.setItem('user_name', localStorage.getItem('user_name')!);
            sessionStorage.setItem('user_id', localStorage.getItem('user_id')!);
        }
        if (sessionId) {
            headers = headers.append('_sessionId', sessionId).append('username', sessionStorage.getItem('user_name')!);
            const projectId: string = sessionStorage.getItem('projectId')!;
            if (projectId) {
                headers = headers.append("projectId", projectId);
            }
        }
        let options = { headers: headers };
        return this.http.patch(url, body, options).pipe(map(res => { return res || {} }), catchError(this.handleError.bind(this)));
    }

    put(url: string, body?: any): Observable<Object> {
        body = body || {};
        /** the  headers should be local variable */
        let headers = new HttpHeaders({ 'Content-type': 'application/json ; charset=utf-8 ' });
        let sessionId: string = sessionStorage.getItem('_sessionId')!;
        if (!sessionId) {
            sessionId = localStorage.getItem('_sessionId')!;
            sessionStorage.setItem('_sessionId', sessionId);
            sessionStorage.setItem('user_name', localStorage.getItem('user_name')!);
            sessionStorage.setItem('user_id', localStorage.getItem('user_id')!);
        }
        if (sessionId) {
            headers = headers.append('_sessionId', sessionId).append('username', sessionStorage.getItem('user_name')!);
            const projectId: string = sessionStorage.getItem('projectId')!;
            if (projectId) {
                headers = headers.append("projectId", projectId);
            }
        }
        let options = { headers: headers };
        return this.http.put(url, body, options).pipe(map(res => { return res || {} }), catchError(this.handleError.bind(this)));
    }

    postFile(url: string, formData: any): Observable<Object> {
        formData = formData || new FormData();
        let headers = new HttpHeaders();
        let sessionId: string = sessionStorage.getItem('_sessionId')!;
        if (!sessionId) {
            sessionId = localStorage.getItem('_sessionId')!;
            sessionStorage.setItem('_sessionId', sessionId);
            sessionStorage.setItem('user_name', localStorage.getItem('user_name')!);
            sessionStorage.setItem('user_id', localStorage.getItem('user_id')!);
        }
        if (sessionId) {
            headers = headers.append('_sessionId', sessionId).append('username', sessionStorage.getItem('user_name')!);
            const projectId: string = sessionStorage.getItem('projectId')!;
            if (projectId) {
                headers = headers.append("projectId", projectId);
            }
        }
        let options = { headers: headers };
        return this.http.post(url, formData, options).pipe(map(res => { return res || {} }), catchError(this.handleError.bind(this)));
    }

    rawPostFile(url: string, formData: any): Observable<Object> {
        return Observable.create((observer: Subject<Object>) => {
            var xhr = new XMLHttpRequest();
            xhr.onreadystatechange = (event: any) => {
                if (xhr.readyState === 4) {
                    if (xhr.status === 200) {
                        observer.next(JSON.parse(xhr.response));
                    } else {
                        observer.error(xhr.response);
                    }
                }
            };

            xhr.upload.addEventListener('progress', (event: ProgressEvent) => {
                console.log(event.loaded);
                let progress = Math.round(event.loaded / event.total * 100);
                this.progress$.next(progress);
            }, false);

            xhr.open('POST', url);
            let sessionId: string = sessionStorage.getItem('_sessionId')!;
            if (!sessionId) {
                sessionId = localStorage.getItem('_sessionId')!;
                sessionStorage.setItem('_sessionId', sessionId);
                sessionStorage.setItem('user_name', localStorage.getItem('user_name')!);
                sessionStorage.setItem('user_id', localStorage.getItem('user_id')!);
            }
            xhr.setRequestHeader('_sessionId', sessionId);
            xhr.setRequestHeader('username', sessionStorage.getItem('user_name')!);
            const projectId: string = sessionStorage.getItem('projectId')!;
            if (projectId) {
                xhr.setRequestHeader('projectId', projectId);
            }
            xhr.send(formData);
        })
    }

    uploadFile4Progress(url: string, formData: any) {
        formData = formData || new FormData();
        let headers = new HttpHeaders();
        let sessionId= sessionStorage.getItem('_sessionId');
        if (!sessionId) {
            sessionId = localStorage.getItem('_sessionId')!;
            sessionStorage.setItem('_sessionId', sessionId);
            sessionStorage.setItem('user_name', localStorage.getItem('user_name')!);
            sessionStorage.setItem('user_id', localStorage.getItem('user_id')!);
        }
        if (sessionId) {
            headers = headers.append('_sessionId', sessionId).append('username', sessionStorage.getItem('user_name')!);
            const projectId: string = sessionStorage.getItem('projectId')!;
            if (projectId) {
                headers = headers.append("projectId", projectId);
            }
        }
        let options = { headers: headers };
        const req = new HttpRequest('POST', url, formData, options);
        // 始终返回一个 `Subscription` 对象，nz-upload 会在适当时机自动取消订阅
        return this.http.request(req)
    }


    private handleError(error: any) {
        console.log(123);
        
        const errMsg = (error.message) ? error.message : error.status ? `${error.status} - ${error.statusText}` : 'Server error';
        if (error.status === 401) {
             sessionStorage.clear();
            localStorage.clear();

            // 优先跳转至第三方登录url

            let href: string = window.location.href;
            if (!href.includes('#')) {
                href = href + this.urlService.defaultRoute;
            }
            window.location.href = this.urlService.loginUrl + '?target=' + str2hex(href);
        } else {
            console.log(errMsg);
        }
        return throwError(errMsg)
    }
}
