import { Injectable } from '@angular/core';

import { NzModalService } from 'ng-zorro-antd/modal';

@Injectable()
export class URLService {

    configPath = 'assets/config.json';
    protocol: string = "";
    ip: string = "";
    port: string = "";
    cleverAppDesign: any;
    oauthUrl: string = "";
    loginUrl: string = "";
    defaultRoute: string = "";
    tumorBoardUrl: string = "";
    imagingExaminationUrl: string = "";
    imagingPetUrl: string = "";
    molecularReportUrl: string = "";
    pathologyReportUrl: string = "";

    CDSSIpAndPort: string = "";
    CDSSApi: string = "";
    CDSSProcessId: string = "";
    CDSSUrl: string = "";
    CDSSAppDesignUrl: string = "";
    CDSSSystemId: string = "";

    constructor(private modalService: NzModalService) {
        this.loadConfigFile();
    }

    loadConfigFile() {
        var xhr = new XMLHttpRequest();
        xhr.addEventListener("load", (data: any) => {
            try {
                var response = JSON.parse(data.target.response);
            } catch (err) {
                this.modalService.error({
                    nzTitle: '错误信息',
                    nzContent: `加载或解析配置文件错误,请检查${this.configPath}是否存在或JSON格式是否正确`
                });
            }

            if (response && response.protocol) {
                this.protocol = response.protocol;
                this.ip = response.ip;
                this.port = response.port;

                this.tumorBoardUrl = `${this.protocol}://${this.ip}:${this.port}`;
                this.cleverAppDesign = response.cleverAppDesign;
                this.oauthUrl = response.oauthUrl;
                this.loginUrl = response.loginUrl;
                this.defaultRoute = response.defaultRoute;

                this.CDSSIpAndPort = response.CDSS.ipAndPort;
                this.CDSSApi = response.CDSS.ipAndPort + response.CDSS.path;
                this.CDSSProcessId = response.CDSS.processId;
                this.CDSSAppDesignUrl = response.CDSS.appDesignUrl;
                this.CDSSSystemId = response.CDSS.systemId;
                this.imagingExaminationUrl = response.imagingExaminationUrl;
                this.molecularReportUrl = response.molecularReportUrl;
                this.imagingPetUrl = response.imagingPetUrl;
                this.pathologyReportUrl = response.pathologyReportUrl;

                this.CDSSUrl = `${this.CDSSApi}?processId=${this.CDSSProcessId}&patientId=`;
            } else {
                this.modalService.error({
                    nzTitle: '错误信息',
                    nzContent: `配置文件存在错误,请按照如下形式：
                    {
                        "protocol":"your protocol",
                        "ip":"your ip",
                        "port": "your port",
                        "name": "your server app name"
                    }`
                });
            }
        });
        xhr.open("GET", this.configPath, false);
        xhr.send();
    }

    // 获取全部的原型域
    // get URL_GET_ALL_OPENEHR_ARCHETYPE_CATEGORIES() { return this.cleverRestUrl + '/archetype/view/category/getAll' };

    get URL_DELETE_LOGOUT() {
        return this.oauthUrl + '/logout/';
    }

    // patient
    get URL_GET_ALL_PATIENT() { return this.tumorBoardUrl + '/patient/getAll' };
    get URL_GET_PATIENT_BY_ID() { return this.tumorBoardUrl + '/patient/getById' };
    get URL_ADD_PATIENT() { return this.tumorBoardUrl + '/patient/add' };
    get URL_DELETE_PATIENT() { return this.tumorBoardUrl + '/patient/delete' };
    get URL_UPDATE_PATIENT() { return this.tumorBoardUrl + '/patient/update' };
    get URL_GET_CDR_PATIENT_BASIC_INFO() { return this.tumorBoardUrl + '/patient/getCdrPatientBasicInfo' };
    get URL_GET_PATIENT_IMAG_REPORT_INFO() { return this.tumorBoardUrl + '/patient/getPatientImagReportInfo' };


    // patientMeetingRecord
    get URL_GET_PATIENT_MEETING_RECORD_BY_ID() { return this.tumorBoardUrl + '/patientMeetingRecord/getByPatientId' };
    get URL_ADD_PATIENT_MEETING_RECORD() { return this.tumorBoardUrl + '/patientMeetingRecord/add' };
    get URL_DELETE_PATIENT_MEETING_RECORD() { return this.tumorBoardUrl + '/patientMeetingRecord/delete' };
    get URL_UPDATE_PATIENT_MEETING_RECORD() { return this.tumorBoardUrl + '/patientMeetingRecord/update' };

    get URL_GET_CLINICAL_TEST_DATA_BY_FILTER_INFO() { return this.tumorBoardUrl + '/clinicalTestData/getByFilterInfo' };
    get URL_DELETE_CLINICAL_TEST_DATA() { return this.tumorBoardUrl + '/clinicalTestData/delete' };
    get URL_UPDATE_CLINICAL_TEST_DATA() { return this.tumorBoardUrl + '/clinicalTestData/update' };
    get URL_GET_CLINICAL_TEST_DATA_SELECT_INFO() { return this.tumorBoardUrl + '/clinicalTestData/getSelectInfo' };

    // 院内临床试验
    get URL_POST_HOSPITAL_CLINICAL_TEST_DATA_BY_FILTER_INFO() { return this.tumorBoardUrl + '/clinicalTestData/hospital/byFilterInfo' };


    get URL_GET_ALL_FORM_COMPLETION_STATUS() { return this.cleverAppDesign.appDesignUrl + '/form-data/getAllFormCompletionStatus' };
    get URL_GET_ALL_FORM_DATA() { return this.cleverAppDesign.appDesignUrl + '/form-data/getEntityAllFormData' };
    get URL_CREATE_ENTITY_IN_APP_DESIGN() { return this.cleverAppDesign.appDesignUrl + '/entity/addEntityInEmbedded' }
    get URL_UPDATE_ENTITY_IN_APP_DESIGN() { return this.cleverAppDesign.appDesignUrl + '/entity/updateEntityInEmbedded' }
    get URL_DELETE_ENTITY_IN_APP_DESIGN() { return this.cleverAppDesign.appDesignUrl + '/entity/delete' }
    get URL_CREATE_ENTITY_IN_CDSS() { return this.CDSSAppDesignUrl + '/entity/addEntityInEmbedded' }
    get URL_UPDATE_ENTITY_IN_CDSS() { return this.CDSSAppDesignUrl + '/entity/updateEntityInEmbedded' }
    get URL_DELETE_ENTITY_IN_CDSS() { return this.CDSSAppDesignUrl + '/entity/delete' }
    //stage predcit
    get URL_POST_STAGE_PREDICT() { return this.tumorBoardUrl + '/stage/predict' };
    get URL_POST_PROGNOSIS_EVALUATION() { return this.tumorBoardUrl + '/prognosis/evaluation' };

    //geneMutation
    get URL_GET_ALL_GENE_MUTATION() { return this.tumorBoardUrl + '/geneMutation/getAll' };
    get URL_GET_GENE_MUTATION_BY_GENE_NAME() { return this.tumorBoardUrl + '/geneMutation/getByGene' };
    get URL_GET_GENE_MUTATION_BY_GENE_DRUG() { return this.tumorBoardUrl + '/geneMutation/getByDrug' };
    get URL_GET_GENE_MUTATION_SELECT_INFO() { return this.tumorBoardUrl + '/geneMutation/getSelectInfo' };
    get URL_GET_GENE_VARIANT_SELECT_INFO() { return this.tumorBoardUrl + '/geneMutation/getVariantSelectInfo' };
    get URL_GET_VARIANT_UNSCRAMBLE_INFO() { return this.tumorBoardUrl + '/geneMutation/getVariantUnscrambleInfo' };
    get URL_GET_GENE_MUTATION_BY_GENE_TEST_INFO() { return this.tumorBoardUrl + '/geneMutation/getGeneMutationByGeneTestInfo' };
    get URL_GET_GENE_GERMLINE_VARIANT_BY_GENE_TEST_INFO() { return this.tumorBoardUrl + '/geneMutation/getGeneGermlineVariantByGeneTestInfo' };

    //PrognosisEvaluation
    get URL_GET_PROGNOSIS_EVALUATION_INFO() { return this.tumorBoardUrl + '/prognosisEvaluation/getPrognosisEvaluationInfo' };

}
