import { Injectable } from '@angular/core';
import { URLService } from "../others/url.service";
import { HttpClient } from "@angular/common/http";

export class ClinicalTestData {
    nctId: string;
    orgFullName: string;
    orgClass: string;
    briefTitle: string;
    officialTitle: string;
    statusVerifiedDate: Date;
    overallStatus: string;
    startDate: Date;
    startDateType: string;
    primaryCompletionDate: Date;
    primaryCompletionDateType: string;
    completionDate: Date;
    completionDateType: string;
    lastUpdatePostDate: Date;
    lastUpdatePostDateType: string;
    briefSummary: string;
    condition: string;
    keyword: string;
    studyType: string;
    phase: string;
    enrollmentCount: number;
    enrollmentType: string;
    gender: string;
    minimumAge: string;
    maximumAge: string;
    studyPopulation: string;
    samplingMethod: string;
    interventionName: string;
    locationCountry: string;
    locationCity: string;
    nsclcStage: string;
    nsclcStageSentencePart: string;
    psMinValue: number;
    psMaxValue: number;
    psSentencePart: string;
    minimumAgeText: string;
    maximumAgeText: string;
    ageSentencePart: string;
    source: string;
    url: string;
}


export class ClinicalTestDataFilterInfo {
    age: number;
    gender: string;
    physicalStrengthScore: number;
    stages: string;
    cancerSpecies: string;
    studyType: string;
    overallStatus: string;
    country: string;
    source: string;
    pageIndex: number;
    limitNumber: any;
    variationInputValue: string;
    gene: string;
    variationType: string;
    variationPosition: string;
    variationWnm: string;
}


@Injectable({
    providedIn: 'root'
})
export class ClinicalTestDataService {

    constructor(private urlService: URLService, private httpClient: HttpClient,) { }


    getByFilterInfo(clinicalTestDataFilterInfo: ClinicalTestDataFilterInfo) {
        return this.httpClient.post(this.urlService.URL_GET_CLINICAL_TEST_DATA_BY_FILTER_INFO, clinicalTestDataFilterInfo);
    }

    deleteClinicalTestData(nctId: string) {
        return this.httpClient.post(this.urlService.URL_DELETE_CLINICAL_TEST_DATA, nctId);
    }

    updateClinicalTestData(clinicalTestData: ClinicalTestData) {
        return this.httpClient.post(this.urlService.URL_UPDATE_CLINICAL_TEST_DATA, clinicalTestData);
    }

    getSelectInfo() {
        return this.httpClient.get(this.urlService.URL_GET_CLINICAL_TEST_DATA_SELECT_INFO);
    }

    getHospitalClinicalTestDataByFilterInfo(hospitalTestData: any, pageIndex: number, limitNumber: number) {
        return this.httpClient.post(this.urlService.URL_POST_HOSPITAL_CLINICAL_TEST_DATA_BY_FILTER_INFO
            + "?pageIndex=" + pageIndex + "&limitNumber=" + limitNumber, hospitalTestData);
    }
}
