import { Injectable } from '@angular/core';
import { URLService } from "../others/url.service";
import { HttpClient } from "@angular/common/http";
import { Subject } from 'rxjs';

export class Patient {
    patientId: string;
    patientIdentifier: string;
    admissionId: string;
    patientName: string;
    gender: string;
    birthdate: Date | any;
    admissionDate: Date | any;
    operationEndDate: Date | any;
    treatDuration: string;
    diagnose: string;
    patientStatus: string;
    meetingId: string;
    creatorId: number;
    creatorName: string;
    createDate: Date;
    updateDate: Date;
    isEnabled: boolean;
    recordList: PatientMeetingRecord[];
    patientDiscussPurpose: string;
    dept: string;

    //前端属性
    iconText: string;
}

export class PatientMeetingRecord {
    reportId: string;
    recordPatientId: string;
    discussPurpose: string;
    discussResult: string;
    recordCreatorId: number;
    recordCreatorName: string;
    recordDate: Date;

    //前端属性
    iconText: string;
}

export class PatientImagReportInfo {
    requesterOrderIdentifier: string;
    examitemName: string;
    conclusion: string;
    findings: string;
    examClassName: string;
    examDeptmentName: string;
    dateTimeIssued: Date;

    //前端属性
    isUnfold: boolean ;
}

@Injectable({
    providedIn: 'root'
})
export class PatientService {

    diagnosisTreatData: any[];
    currentPatient: any;


    /**
     *  other component can subscribe this subject to get the diagnosisTreatData
     */
    diagnosisTreatDataSubject$ = new Subject<any>();

    // 发布诊疗数据
    announceDiagnosisTreatData(diagnosisTreatData: any) {
        this.diagnosisTreatDataSubject$.next(diagnosisTreatData);
    }


    constructor(private urlService: URLService, private httpClient: HttpClient) {
    }


    getAllPatient() {
        return this.httpClient.get(this.urlService.URL_GET_ALL_PATIENT);
    }

    getPatientById(patientId: string) {
        return this.httpClient.get(this.urlService.URL_GET_PATIENT_BY_ID, { params: { patientId } });
    }

    getCdrPatientBasicInfo(patientIdentifier: string) {
        return this.httpClient.get(this.urlService.URL_GET_CDR_PATIENT_BASIC_INFO, { params: { patientIdentifier } });
    }

    addPatient(patient: Patient) {
        return this.httpClient.post(this.urlService.URL_ADD_PATIENT, patient);
    }

    deletePatient(patientId: string) {
        return this.httpClient.post(this.urlService.URL_DELETE_PATIENT, patientId);
    }

    updatePatient(patient: Patient) {
        return this.httpClient.post(this.urlService.URL_UPDATE_PATIENT, patient);
    }

    getPatientImagReportInfo(patientIdentifier: string) {
        return this.httpClient.get(this.urlService.URL_GET_PATIENT_IMAG_REPORT_INFO, { params: { patientIdentifier } });
    }


    getPatientMeetingRecordById(patientId: string) {
        return this.httpClient.get(this.urlService.URL_GET_PATIENT_MEETING_RECORD_BY_ID, { params: { patientId } });
    }

    addPatientMeetingRecord(patientMeetingRecord: PatientMeetingRecord) {
        return this.httpClient.post(this.urlService.URL_ADD_PATIENT_MEETING_RECORD, patientMeetingRecord);
    }

    deletePatientMeetingRecord(recordId: string) {
        return this.httpClient.post(this.urlService.URL_DELETE_PATIENT_MEETING_RECORD, recordId);
    }

    updatePatientMeetingRecord(patientMeetingRecord: PatientMeetingRecord) {
        return this.httpClient.post(this.urlService.URL_UPDATE_PATIENT_MEETING_RECORD, patientMeetingRecord);
    }

    getAllFormCompletionStatus(entityId: string) {
        let systemId = this.urlService.cleverAppDesign.systemId;
        return this.httpClient.get(this.urlService.URL_GET_ALL_FORM_COMPLETION_STATUS, { params: { entityId, systemId } });
    }

    getEntityAllFormData(entityId: string) {
        let systemId = this.urlService.cleverAppDesign.systemId;
        return this.httpClient.get(this.urlService.URL_GET_ALL_FORM_DATA, { params: { entityId, systemId } });
    }


    addAppDesignEntity(entity: any) {
        entity.systemId = this.urlService.cleverAppDesign.systemId;
        return this.httpClient.post(this.urlService.URL_CREATE_ENTITY_IN_APP_DESIGN, entity);
    }

    updateAppDesignEntity(oldEntityId: string, entityId: string) {
        return this.httpClient.get(this.urlService.URL_UPDATE_ENTITY_IN_APP_DESIGN, { params: { oldEntityId, entityId } });
    }

    deleteAppDesignEntity(entityId: string) {
        return this.httpClient.post(this.urlService.URL_DELETE_ENTITY_IN_APP_DESIGN, entityId);
    }

    addCdssEntity(entity: any) {
        entity.systemId = this.urlService.CDSSSystemId;
        return this.httpClient.post(this.urlService.URL_CREATE_ENTITY_IN_CDSS, entity);
    }

    updateCdssEntity(oldEntityId: string, entityId: string) {
        return this.httpClient.get(this.urlService.URL_UPDATE_ENTITY_IN_CDSS, { params: { oldEntityId, entityId } });
    }

    deleteCdssEntity(entityId: string) {
        return this.httpClient.post(this.urlService.URL_DELETE_ENTITY_IN_CDSS, entityId);
    }
}
