import { Injectable } from '@angular/core';
import {HttpParams} from "@angular/common/http";

export function getGlobalQueryParams() {
    if (!window.location.href.includes('?')) {
        return null;
    }
    return new HttpParams({fromString: window.location.href.split('?')[1]});
}

@Injectable()
export class Utils {
    constructor() { }
    toArray = function (value: any) {
        if (value) {
            if (value instanceof Array) {
                return value;
            }
            else {
                return [value];
            }
        } else {
            return [] as any;
        }

    }

    formatTime(date: any): string {
        if (date) {
            date = new Date(date);
            let h = date.getHours();
            let minute: string | number = date.getMinutes();
            minute = minute < 10 ? ('0' + minute) : minute;
            let second: string | number = date.getSeconds();
            second = second < 10 ? ('0' + second) : second;
            return h + ':' + minute + ':' + second;
        } else {
            return '';
        }

    }

    formatDate(date: any): string {
        if (date) {
            date = new Date(date);
            const y = date.getFullYear();
            let m: string | number = date.getMonth() + 1;
            m = m < 10 ? ('0' + m) : m;
            let d: string | number = date.getDate();
            d = d < 10 ? ('0' + d) : d;
            return y + '-' + m + '-' + d;
        } else {
            return '';
        }
    }

    formatDateTime(date: Date): string {
        return date ? this.formatDate(date) + ' ' + this.formatTime(date) : '';
    }


    // error TS2339: Property 'trimLeft' does not exist on type 'string'.   es2018存在的bug
    leftTrim(str: string) {
        if (str) {
            return str.replace(/^\s+/, "");
        } else {
            return '';
        }
    }

    //根据出生日期及指定日期计算年龄
    getAge(startDate: Date, endDate: Date): number {
        let age = 0;
        let startYear = startDate.getFullYear();
        let endYear = endDate.getFullYear();

        if (endYear != startYear) {
            age = Math.abs(endYear - startYear);
            if (startDate.getMonth() == endDate.getMonth()) {
                if (endDate.getDate() - startDate.getDate() < 0) {
                    age = age - 1;
                }
            } else {
                if (endDate.getMonth() - startDate.getMonth() < 0) {
                    age = age - 1;
                }
            }
        }
        return age;
    }

    //根据日期字符串计算年龄
    getAgeByDateStr(startDateStr: string, endDateStr: string): number {
        let age = 0;
        let startDate: Date = new Date(startDateStr);
        let endDate: Date = new Date(endDateStr);
        let startYear = startDate.getFullYear();
        let endYear = endDate.getFullYear();

        if (endYear != startYear) {
            age = Math.abs(endYear - startYear);
            if (startDate.getMonth() == endDate.getMonth()) {
                if (endDate.getDate() - startDate.getDate() < 0) {
                    age = age - 1;
                }
            } else {
                if (endDate.getMonth() - startDate.getMonth() < 0) {
                    age = age - 1;
                }
            }
        }
        return age;
    }

    //根据日期字符串计算与当前日期相差天数
    getDiffDaysByDateStr(startDateStr: string): number {
        let startDate: number = Date.parse(startDateStr);
        let endDate: number = new Date().getTime();
        return Math.floor(Math.abs(endDate - startDate) / (24 * 3600 * 1000));
    }



}
