import { Component, Input, OnInit, ViewChild, ElementRef } from '@angular/core';

import { FormBuilder, FormGroup } from '@angular/forms';
import {
    ClinicalTestData,
    ClinicalTestDataFilterInfo,
    ClinicalTestDataService
} from "../../core/service/clinical-test-data.service";
import { StagePredictService } from "../../core/service/stage-predict.service";

@Component({
    selector: 'app-clinic-test-recommend',
    templateUrl: './clinic-test-recommend.component.html',
    styleUrls: ['./clinic-test-recommend.component.css']
})
export class ClinicTestRecommendComponent implements OnInit {

    @Input()
    public patient: any;

    hospitalDeptList: any = [];

    hosptalTestFilterForm: FormGroup;
    hosptalTestDataList: any = [];
    hosptalTestDataListLoading: boolean = false;
    totalHosptalTestData: number = 0;

    clinicalTestDetailPageModelVisible = false;
    overallStatusList: string[] = [];
    locationCountryList = [];
    checkCondition: boolean[] = [true, true, true, true, true];
    geneList = [];
    variationTypeList = [];
    variationPositionList = [];
    variationWnmList = [];
    clinicalTestDataFilterInfo: ClinicalTestDataFilterInfo;

    studyType: string;
    overallStatus: string;
    country: string;
    source: string;
    gene: any;
    variationType: any;
    variationPosition: any;
    variationWnm: any;
    variationInputValue: any;


    pageIndex = 1;
    clinicalTestDatatotal = 0;
    topClinicalTestDataList: ClinicalTestData[] = [];
    clinicalTestDataList: any = [];
    loadingList = false;

    constructor(private clinicalTestDataService: ClinicalTestDataService, private fb: FormBuilder,
        public stagePredictService: StagePredictService) { }

    async ngOnInit() {
        this.stagePredictService.stageDataSubject$.subscribe((stage: any) => {
            this.setClinicalTestDataFilterInfo();
            this.getClinicalTestDataList();
        });

        // 得到临床试验的类型、状态、国家、来源、基因、变异类型、变异位置、氨基酸变化
        let result = await this.clinicalTestDataService.getSelectInfo().toPromise() as any;
        this.overallStatusList = result.status;
        this.locationCountryList = result.country;
        this.hospitalDeptList = result.hospitalDeptList;
        this.geneList = result.geneList;
        this.variationTypeList = result.variationTypeList;
        this.variationPositionList = result.variationPositionList;
        this.variationWnmList = result.variationWnmList;

        this.hosptalTestFilterForm = this.fb.group({
            groupDescribe: [null, []],
            deptInCharge: [null, []],
            stage: [null, []],
            domesticOrInternational: [null, []],
            startDate: [null, []],
            endDate: [null, []],
        });
        this.getHospitalClinicalTestDataList();
    }

    async getClinicalTestDataList() {
        try {
            this.loadingList = true;
            this.clinicalTestDataFilterInfo.pageIndex = this.pageIndex;
            if (this.clinicalTestDetailPageModelVisible) {
                this.clinicalTestDataFilterInfo.limitNumber = null;
                let result = await this.clinicalTestDataService.getByFilterInfo(this.clinicalTestDataFilterInfo).toPromise() as any;
                this.clinicalTestDataList = result.list;
                this.clinicalTestDatatotal = result.total;
            } else {
                this.clinicalTestDataFilterInfo.limitNumber = 2;
                let result = await this.clinicalTestDataService.getByFilterInfo(this.clinicalTestDataFilterInfo).toPromise() as any;
                this.topClinicalTestDataList = result.list;
            }
        } catch (e) {
            console.log(e);
        } finally {
            this.loadingList = false;
        }
    }

    resetHospitalTestFilterForm(e: MouseEvent): void {
        e.preventDefault();
        this.hosptalTestFilterForm.reset();
        for (const key in this.hosptalTestFilterForm.controls) {
            this.hosptalTestFilterForm.controls[key].markAsPristine();
            this.hosptalTestFilterForm.controls[key].updateValueAndValidity();
        }
    }

    hospitalPageIndex = 1;
    hospitalPageSize = 5;
    async getHospitalClinicalTestDataList() {
        try {
            this.hosptalTestDataListLoading = true;

            let result = await this.clinicalTestDataService.getHospitalClinicalTestDataByFilterInfo(this.hosptalTestFilterForm.value, this.hospitalPageIndex, this.hospitalPageSize).toPromise() as any;
            this.hosptalTestDataList = result.hospitalTestDataList;
            this.totalHosptalTestData = result.total;
        } catch (error) {
            console.log(error);
        } finally {
            this.hosptalTestDataListLoading = false;
        }

    }

    async checkFilterCondition(event?: any) {
        if (event != null) {
            this.checkCondition[event] = !this.checkCondition[event];
        }
        this.setClinicalTestDataFilterInfo();
        await this.getClinicalTestDataList();
    }

    setClinicalTestDataFilterInfo() {
        this.clinicalTestDataFilterInfo = new ClinicalTestDataFilterInfo();
        if (this.checkCondition[0]) {
            this.clinicalTestDataFilterInfo.age = this.patient.age;
        }
        if (this.checkCondition[1]) {
            if (this.patient.gender == '男') {
                this.clinicalTestDataFilterInfo.gender = 'Male';
            } else {
                this.clinicalTestDataFilterInfo.gender = 'Female';
            }
        }
        if (this.checkCondition[2]) {
            if (this.stagePredictService.ecog != undefined && this.stagePredictService.ecog != null) {
                this.clinicalTestDataFilterInfo.physicalStrengthScore = this.stagePredictService.ecog;
            }
        }
        if (this.checkCondition[3]) {
            if (this.stagePredictService.stage != undefined && this.stagePredictService.stage != null) {
                this.clinicalTestDataFilterInfo.stages = '%' + this.stagePredictService.stage + '%';
            }
        }
        if (this.checkCondition[4]) {
            this.clinicalTestDataFilterInfo.cancerSpecies = '%Lung Cancer%';
        }
        this.clinicalTestDataFilterInfo.studyType = this.studyType;
        this.clinicalTestDataFilterInfo.overallStatus = this.overallStatus;
        this.clinicalTestDataFilterInfo.country = this.country;
        this.clinicalTestDataFilterInfo.source = this.source;
        this.clinicalTestDataFilterInfo.variationInputValue = this.variationInputValue;
        this.clinicalTestDataFilterInfo.gene = this.gene;
        this.clinicalTestDataFilterInfo.variationPosition = this.variationPosition;
        this.clinicalTestDataFilterInfo.variationType = this.variationType;
        this.clinicalTestDataFilterInfo.variationWnm = this.variationWnm;
    }

    closeClinicalTestDetailPageModel() {
        this.clinicalTestDetailPageModelVisible = false;
        this.getClinicalTestDataList();
    }

    resetVariationFilterInfo(){
        this.variationInputValue = null;
        this.gene = null;
        this.variationPosition = null;
        this.variationType = null;
        this.variationWnm = null;
        this.checkFilterCondition();
    }
}
