import { Component, Input, OnInit, Renderer2 } from '@angular/core';
import { DomSanitizer } from '@angular/platform-browser';

import { URLService } from '../../core/others/url.service';

@Component({
    selector: 'app-clinical-guideline',
    templateUrl: './clinical-guideline.component.html',
    styleUrls: ['./clinical-guideline.component.css']
})
export class ClinicalGuidelineComponent implements OnInit {

    @Input()
    patientId: any;

    previewCdssUrl: any;
    detailPageCdssUrl: any;

    guidelineDetailPageModelVisible: boolean;

    guldeLineResult: any;
    guldeLineResultChange: any;
    acquiredData = false;
    isShowImageModal = false;
    constructor(private urlService: URLService, private sanitized: DomSanitizer, private renderer: Renderer2) {
    }

    ngOnInit(): void {
        let userId = sessionStorage.getItem('user_id');
        let url = this.urlService.CDSSUrl + this.patientId + "&preview=true&isContinue=true&userId=" + userId;
        this.previewCdssUrl = this.sanitized.bypassSecurityTrustResourceUrl(url);
        url = this.urlService.CDSSUrl + this.patientId + "&hiddenTitle=true&hiddenButton=true&hiddenLog=true&isContinue=true&hiddenResult=true&userId=" + userId;
        this.detailPageCdssUrl = this.sanitized.bypassSecurityTrustResourceUrl(url);
    }

    ngAfterViewInit(): void {
        this.renderer.listen('window', 'message', (event) => {
            if (event.origin == this.urlService.CDSSIpAndPort && !this.acquiredData) {
                this.guldeLineResult = JSON.parse(event.data);
                if (this.guldeLineResult && this.guldeLineResult.guideline && this.guldeLineResult.guideline.text) {
                    this.acquiredData = true;
                }
                console.log(this.guldeLineResult);
            }
        });
    }

    showImageModal() {
        this
    }
}
