import { Component, Input, OnInit, ViewChild } from '@angular/core';
import { PatientImagReportInfo, PatientService } from "../../core/service/patient.service";
import { GeneMutationService } from "../../core/service/gene-mutation.service";
import { TreatmentHistoryComponent } from "./treatment-history/treatment-history.component";
import { URLService } from "../../core/others/url.service";
import { ActivatedRoute, Router } from "@angular/router";
import { Utils } from "../../core/utils/utils.service";

@Component({
    selector: 'app-diagnosis-treat',
    templateUrl: './diagnosis-treat.component.html',
    styleUrls: ['./diagnosis-treat.component.css']
})
export class DiagnosisTreatComponent implements OnInit {

    @Input() patientIdentifier: string;
    isVisibleModel = false;
    diagnosisTreatData: any[];
    medicalHistory: any;
    diseaseHistoryList: any[] = [];
    inspectionDataList: PatientImagReportInfo[];
    inspectClassList: any[] = [];
    allInspectionDataList: PatientImagReportInfo[];
    pathologyData: any;
    patientBasicInfo: any;
    showInDiagnosisTreat: boolean = false;
    complicationClassList: string[] = ['pulmonary_insufficiency', 'liver_dysfunction', 'renal__insufficiency', 'cardiac_insufficiency', 'immune_system_diseases', 'cerebrovascular_disease', 'nervous_system_diseases', 'mental_illness'];
    topShowDiagnosisTreatInfo: any = {};
    patientId: any;
    nzSelectedTabIndex = 0;
    treatmentHistoryData: any[] = [];
    showTreatmentHistoryData: any[] = [];
    examinationBeforeTreatment: any;
    inspectTreatmentHistoryList: any = {
        CT: [],
        PET: [],
        pathology: [],
        other: []
    };
    treatmentEvaluation: any = {
        'CR': '#3ab000',
        'PR': '#87d068',
        '缩小SD': '#FBA546',
        '增大SD': '#FBA546',
        'PD': '#cd201f',
    };
    @ViewChild('appTreatmentHistory') appTreatmentHistory: TreatmentHistoryComponent;
    geneticTest: string[] = ['egfr', 'alk', 'kras'];
    lymphNodeDissectionNumber: string[] = ['1l', '1r', '2l', '2r', '2r+4r', '3a', '3p', '4l', '4r', '5', '6', '7', '8', '9', '10', '11', '12', '13', '14'];

    constructor(private patientService: PatientService,
        private geneMutationService: GeneMutationService,
        private route: ActivatedRoute,
        private router: Router,
        private utils: Utils) {
        this.route.queryParams.subscribe((res) => {
            this.patientId = res.patientId;
            this.patientIdentifier = res.patientIdentifier;
            this.showInDiagnosisTreat = res.showInDiagnosisTreat
        });
    }

    async ngOnInit() {
        await this.initDiagnosisTreatData();
    }

    async initDiagnosisTreatData() {
        let results: any[] = await Promise.all([
            this.patientService.getEntityAllFormData(this.patientIdentifier).toPromise() as any,
            this.patientService.getPatientImagReportInfo(this.patientIdentifier).toPromise() as any,
        ]);
        this.patientService.diagnosisTreatData = this.diagnosisTreatData = results[0];
        this.patientService.announceDiagnosisTreatData(this.diagnosisTreatData);
        this.geneMutationService.geneReportDataList = [];
        if (results[1] && results[1] instanceof Array && results[1].length > 0) {
            this.allInspectionDataList = results[1];
            this.inspectionDataList = results[1].filter(item => !item.examClassName || item?.examClassName?.indexOf('分子') == -1);
            this.inspectClassList = Array.from(new Set(this.inspectionDataList.filter(item => item.examClassName).map(item => item.examClassName)));
            this.geneMutationService.geneReportDataList = results[1].filter(item => item.examClassName && item.examClassName.indexOf('分子') != -1);
        }
        if (this.diagnosisTreatData) {
            this.medicalHistory = this.diagnosisTreatData.find(item => item.id == "病史信息");
            if (this.medicalHistory && this.medicalHistory.data) {
                this.medicalHistory = this.medicalHistory.data;
                this.setDiseaseHistoryList()
            }
            this.examinationBeforeTreatment = this.diagnosisTreatData.find(item => item.id == "治疗前检查检验");
            if (this.examinationBeforeTreatment && this.examinationBeforeTreatment.data) {
                this.examinationBeforeTreatment = this.examinationBeforeTreatment.data;
                for (let complicationClass of this.complicationClassList) {
                    if (this.examinationBeforeTreatment[complicationClass] && this.examinationBeforeTreatment[complicationClass] != '') {
                        this.examinationBeforeTreatment.isShowMajorComplication = true;
                        break;
                    }
                }
            }
            this.pathologyData = this.diagnosisTreatData.find(item => item.id == "手术");
            if (this.pathologyData && this.pathologyData.data) {
                this.pathologyData = this.pathologyData.data;
                if (this.pathologyData.egfr_mutations) {
                    this.pathologyData.egfr_mutations = JSON.parse(this.pathologyData.egfr_mutations);
                }
            }
            this.patientBasicInfo = this.diagnosisTreatData.find(item => item.id == "患者当前基本信息");
            if (this.patientBasicInfo && this.patientBasicInfo.data) {
                this.patientBasicInfo = this.patientBasicInfo.data;
            }
            this.setTreatmentHistory();
        }
    }

    //设置病人疾病史信息
    setDiseaseHistoryList() {
        if (this.medicalHistory.disease_name) {
            this.diseaseHistoryList.push({
                disease_name: this.medicalHistory.disease_name,
                illness_year: this.medicalHistory.illness_year,
                is_operation: this.medicalHistory.is_operation,
            });
        }
        let diseaseHistoryList = this.medicalHistory.item_6;
        if (diseaseHistoryList && diseaseHistoryList instanceof Array) {
            for (let diseaseHistory of diseaseHistoryList) {
                if (diseaseHistory.disease_name) {
                    this.diseaseHistoryList.push({
                        disease_name: diseaseHistory.disease_name,
                        illness_year: diseaseHistory.illness_year,
                        is_operation: diseaseHistory.is_operation,
                    });
                }
            }
        }
    }

    unVisibleDiagnosisModal() {
        this.isVisibleModel = false;
        this.shrinkTimeline();
    }

    setTreatmentHistory() {
        let earliestInspetcDate;
        //设置检查信息
        if (this.allInspectionDataList && this.allInspectionDataList.length > 0) {
            for (let inspect of this.allInspectionDataList) {
                inspect.dateTimeIssued = new Date(inspect.dateTimeIssued);
                if (!earliestInspetcDate || earliestInspetcDate >= inspect.dateTimeIssued) {
                    earliestInspetcDate = inspect.dateTimeIssued;
                }
                if (inspect.examClassName == 'CT') {
                    this.inspectTreatmentHistoryList.CT.push(inspect);
                } else if (inspect.examClassName == 'PET') {
                    this.inspectTreatmentHistoryList.PET.push(inspect);
                } else if (inspect.examClassName == '病理') {
                    this.inspectTreatmentHistoryList.pathology.push(inspect);
                } else {
                    this.inspectTreatmentHistoryList.other.push(inspect);
                }
            }
        }
        //设置新辅助治疗信息
        this.setTreatmentHistoryNeoadjuvantTherapy();
        //设置辅助治疗信息
        this.setTreatmentHistoryAdjuvantTherapy();
        //设置用药治疗方案
        this.setTreatmentHistoryTherapyPlan();
        //设置手术信息
        this.setTreatmentHistoryOperation();
        //设置复发信息
        this.setTreatmentHistoryRecrudescence();
        if (this.showTreatmentHistoryData.length > 0) {
            //节点按时间进行排序
            this.showTreatmentHistoryData.sort(function (a: any, b: any) {
                return a.startDate - b.startDate
            });
            //将未录入结束时间的节点的结束时间设置为下一个节点的开始时间
            for (let i = 0; i < this.showTreatmentHistoryData.length; i++) {
                if (!this.showTreatmentHistoryData[i].endDate && i != this.showTreatmentHistoryData.length - 1) {
                    this.showTreatmentHistoryData[i].endDate = this.showTreatmentHistoryData[i + 1].startDate;
                }
                this.showTreatmentHistoryData[this.showTreatmentHistoryData.length - 1].endDate = new Date();
            }
            if (this.inspectionDataList && this.inspectionDataList.length > 0) {
                //设置治疗历史中检查检验信息
                this.setTreatmentHistoryInspect();
            }
        }
        //设置标记至时间轴疾病信息
        this.setMarkToTimelineDisease();
        //设置关键诊疗数据补充
        this.setKeyDiagnosisTreatmentData();
        //设置治疗前检查检验数据
        this.setExaminationBeforeTreatData();
        this.showTreatmentHistoryData.sort(function (a: any, b: any) {
            return a.startDate - b.startDate
        });
        //设置患者基本信息
        this.setPatientBasicInfo();
    }

    setMarkToTimelineDisease() {
        if (this.medicalHistory) {
            if (this.medicalHistory.mark_to_timeline == 'true' && this.medicalHistory.time_of_diagnosis && this.medicalHistory.disease_name) {
                this.showTreatmentHistoryData.push({
                    title: this.medicalHistory.disease_name,
                    startDate: new Date(this.medicalHistory.time_of_diagnosis),
                    detaileInfo: this.medicalHistory.treatment_information,
                    summary: this.medicalHistory.summary,
                    type: "疾病",
                    isUnfold: false
                });
            }
            let diagnosisInfoList = this.medicalHistory.item_6;
            if (diagnosisInfoList && diagnosisInfoList instanceof Array) {
                for (let diagnosisInfo of diagnosisInfoList) {
                    if (diagnosisInfo.mark_to_timeline == 'true' && diagnosisInfo.time_of_diagnosis && diagnosisInfo.disease_name) {
                        this.showTreatmentHistoryData.push({
                            title: diagnosisInfo.disease_name,
                            startDate: new Date(diagnosisInfo.time_of_diagnosis),
                            detaileInfo: diagnosisInfo.treatment_information,
                            summary: diagnosisInfo.summary,
                            type: "疾病",
                            isUnfold: false
                        });
                    }
                }
            }

        }
    }

    setTreatmentHistoryNeoadjuvantTherapy() {
        let neoadjuvantTherapyDataList = this.diagnosisTreatData.filter(item => item.id == "新辅助治疗");
        for (let neoadjuvantTherapyData of neoadjuvantTherapyDataList) {
            if (neoadjuvantTherapyData && neoadjuvantTherapyData.data) {
                neoadjuvantTherapyData = neoadjuvantTherapyData.data;
                this.setTreatmentHistoryAdjuvantOrNeoadjuvantTherapyInfo(neoadjuvantTherapyData, "新辅助治疗");
            }
        }
    }

    setTreatmentHistoryAdjuvantTherapy() {
        let adjuvantTherapyDataList = this.diagnosisTreatData.filter(item => item.id == "辅助治疗");
        for (let adjuvantTherapyData of adjuvantTherapyDataList) {
            if (adjuvantTherapyData && adjuvantTherapyData.data && adjuvantTherapyData.data.treatment_protocol) {
                adjuvantTherapyData = adjuvantTherapyData.data;
                this.setTreatmentHistoryAdjuvantOrNeoadjuvantTherapyInfo(adjuvantTherapyData, "辅助治疗");
            }
        }
    }

    setTreatmentHistoryAdjuvantOrNeoadjuvantTherapyInfo(data: any, title: string) {
        let startDate: any = data.time_to_initiation_therapy ? new Date(data.time_to_initiation_therapy) : null;
        let endDate: any = data.time_to_end_treatment ? new Date(data.time_to_end_treatment) : null;
        let children: any = [];
        if (startDate) {
            data.treatmentProtocol = data.treatment_protocol;
            if (endDate) {
                children.push(...this.treatmentHistoryData.filter(item => item.date > startDate && item.date < endDate));
            }
            if (title == '新辅助治疗') {
                let tumorSizeInfoList: any[] = [];
                let showOption: any = {
                    tooltip: {
                        trigger: 'axis'
                    },
                    legend: {
                        data: ['总计'],
                        orient: 'vertical',
                        right: 0,
                        top: 20,
                        bottom: 20,
                        selected: {

                        }
                    },
                    toolbox: {
                        show: false,
                    },
                    xAxis: {
                        name: '周期',
                        type: 'category',
                        boundaryGap: false,
                        data: ['基线'],
                    },
                    yAxis: {
                        name: '大小',
                        type: 'value',
                        axisLabel: {
                            formatter: '{value} mm'
                        }
                    },
                    grid: {
                        x2: 150,
                        borderWidth: 1
                    },
                    series: [
                        {
                            name: '总计',
                            type: 'line',
                            data: [],
                            markPoint: {
                                data: []
                            },
                        },
                    ]
                };
                let baselinePosition = this.setTreatmentHistoryTherapyBaseLine(data, tumorSizeInfoList, showOption);;
                if (data.cycle && data.therapeutic_evaluation) {
                    this.setTreatmentHistoryTherapyPlanCycle(data, tumorSizeInfoList, showOption)
                }
                let cycles = data.item_3;
                let evaluation;
                if (cycles && cycles instanceof Array && cycles.length > 0) {
                    evaluation = cycles[cycles.length - 1].therapeutic_evaluation;
                    for (let cycle of cycles) {
                        this.setTreatmentHistoryTherapyPlanCycle(cycle, tumorSizeInfoList, showOption)
                    }
                }
                let isShowTable = false;
                if (baselinePosition && baselinePosition.length > 0 && tumorSizeInfoList.length > 0) {
                    isShowTable = true;
                }
                let tumorMarkers = [];
                if (data.inspect_time) {
                    tumorMarkers.push({
                        date: data.inspect_time,
                        cea: data.cea,
                        ca199: data.ca199,
                        ca125: data.ca125,
                        nse: data.nse,
                        cyfra21_1: data.cyfra21_1,
                        scc: data.scc,
                    })
                }
                let tumorMarkerItems = data.item_8;
                if (tumorMarkerItems && tumorMarkerItems instanceof Array && tumorMarkerItems.length > 0) {
                    for (let tumorMarkerItem of tumorMarkerItems) {
                        if (tumorMarkerItem.inspect_time) {
                            tumorMarkers.push({
                                date: tumorMarkerItem.inspect_time,
                                cea: tumorMarkerItem.cea,
                                ca199: tumorMarkerItem.ca199,
                                ca125: tumorMarkerItem.ca125,
                                nse: tumorMarkerItem.nse,
                                cyfra21_1: tumorMarkerItem.cyfra21_1,
                                scc: tumorMarkerItem.scc,
                            })
                        }
                    }
                }
                this.showTreatmentHistoryData.push({
                    title: title,
                    startDate: startDate,
                    endDate: endDate,
                    type: title,
                    data: data,
                    evaluation: evaluation,
                    children: children,
                    showInspect: false,
                    isUnfold: false,
                    summary: data.treatment_protocol,
                    stageType: 'yc',
                    t: data.yct,
                    n: data.ycn,
                    m: data.ycm,
                    baselinePosition: baselinePosition,
                    tumorSizeInfoList: tumorSizeInfoList,
                    showOption: showOption,
                    tumorMarkers: tumorMarkers,
                    isShowTable: isShowTable
                });
            } else {
                this.showTreatmentHistoryData.push({
                    title: title,
                    startDate: startDate,
                    endDate: endDate,
                    type: title,
                    data: data,
                    children: children,
                    showInspect: false,
                    isUnfold: false,
                    summary: data.treatment_protocol,
                    stageType: data.pathological_stage_type,
                    t: data.t,
                    n: data.n,
                    m: data.m,

                });
            }

        }
    }

    setTreatmentHistoryTherapyPlan() {
        let therapyInfoDataList = this.diagnosisTreatData.filter(item => item.id == "用药治疗方案");
        for (let therapyInfoData of therapyInfoDataList) {
            let title;
            if (therapyInfoData && therapyInfoData.data && therapyInfoData.data.time_to_treatment_initiation && therapyInfoData.data.treatment_protocol) {
                title = therapyInfoData.metadata.formInstanceId;
                if (title.indexOf('未录入') != -1) {
                    title = '用药治疗方案';
                }
                therapyInfoData = therapyInfoData.data;
                let tumorSizeInfoList: any[] = [];
                let showOption: any = {
                    tooltip: {
                        trigger: 'axis'
                    },
                    legend: {
                        data: ['总计'],
                        orient: 'vertical',
                        right: 0,
                        top: 20,
                        bottom: 20,
                        selected: {

                        }
                    },
                    toolbox: {
                        show: false,
                    },
                    xAxis: {
                        name: '周期',
                        type: 'category',
                        boundaryGap: false,
                        data: ['基线'],
                    },
                    yAxis: {
                        name: '大小',
                        type: 'value',
                        axisLabel: {
                            formatter: '{value} mm'
                        }
                    },
                    grid: {
                        x2: 150,
                        borderWidth: 1
                    },
                    series: [
                        {
                            name: '总计',
                            type: 'line',
                            data: [],
                            markPoint: {
                                data: []
                            },
                        },
                    ]
                };
                let baselinePosition = this.setTreatmentHistoryTherapyBaseLine(therapyInfoData, tumorSizeInfoList, showOption);;
                if (therapyInfoData.cycle && therapyInfoData.therapeutic_evaluation) {
                    this.setTreatmentHistoryTherapyPlanCycle(therapyInfoData, tumorSizeInfoList, showOption)
                }
                let cycles = therapyInfoData.item_3;
                if (cycles && cycles instanceof Array && cycles.length > 0) {
                    for (let cycle of cycles) {
                        this.setTreatmentHistoryTherapyPlanCycle(cycle, tumorSizeInfoList, showOption)
                    }
                }
                let startDate: any = new Date(therapyInfoData.time_to_treatment_initiation);
                let endDate: any = new Date(therapyInfoData.end_of_treatment_time);
                let isShowTable = false;
                if (baselinePosition && baselinePosition.length > 0 && tumorSizeInfoList.length > 0) {
                    isShowTable = true;
                }
                if (startDate) {
                    this.showTreatmentHistoryData.push({
                        title: title,
                        startDate: startDate,
                        endDate: endDate,
                        type: "用药治疗方案",
                        data: therapyInfoData,
                        baselinePosition: baselinePosition,
                        tumorSizeInfoList: tumorSizeInfoList,
                        isShowTable: isShowTable,
                        showInspect: false,
                        isUnfold: false,
                        summary: therapyInfoData.treatment_protocol,
                        surviva: therapyInfoData.progression_free_survival,
                        showOption: showOption
                    });
                }
            }
        }
    }

    setTreatmentHistoryTherapyBaseLine(therapyInfoData: any, tumorSizeInfoList: any, showOption: any) {
        let tumorSizeInfo: any = {};
        let baselinePosition = [];
        if (therapyInfoData.position) {
            baselinePosition.push(therapyInfoData.position);
            tumorSizeInfo[therapyInfoData.position] = {
                longDiameter: therapyInfoData.long_diameter,
                shortDiameter: therapyInfoData.short_diameter,
            };
            showOption.legend.data.push(therapyInfoData.position + "长径");
            showOption.legend.selected[therapyInfoData.position + "长径"] = false;
            showOption.legend.data.push(therapyInfoData.position + "短径");
            showOption.legend.selected[therapyInfoData.position + "短径"] = false;
            showOption.series.push({
                name: therapyInfoData.position + "长径",
                type: 'line',
                data: [therapyInfoData.long_diameter],
            });
            showOption.series.push({
                name: therapyInfoData.position + "短径",
                type: 'line',
                data: [therapyInfoData.short_diameter],
            });
        }
        let baselineDataList = therapyInfoData.item_2;
        if (baselineDataList && baselineDataList instanceof Array && baselineDataList.length > 0) {
            for (let baselineData of baselineDataList) {
                if (baselineData.position) {
                    baselinePosition.push(baselineData.position);
                    tumorSizeInfo[baselineData.position] = {
                        longDiameter: baselineData.long_diameter,
                        shortDiameter: baselineData.short_diameter,
                    };
                    showOption.legend.data.push(baselineData.position + "长径");
                    showOption.legend.selected[baselineData.position + "长径"] = false;
                    showOption.legend.data.push(baselineData.position + "短径");
                    showOption.legend.selected[baselineData.position + "短径"] = false;
                    showOption.series.push({
                        name: baselineData.position + "长径",
                        type: 'line',
                        data: [baselineData.long_diameter],
                    });
                    showOption.series.push({
                        name: baselineData.position + "短径",
                        type: 'line',
                        data: [baselineData.short_diameter],
                    });
                }
            }
        }
        tumorSizeInfo["cycle"] = "基线";
        tumorSizeInfo["total"] = therapyInfoData.total;
        tumorSizeInfo["evaluation"] = "";
        tumorSizeInfo["remark"] = "";
        tumorSizeInfoList.push(tumorSizeInfo);
        if (therapyInfoData.total) {
            showOption.series[0].data.push(therapyInfoData.total);
        }
        return baselinePosition;
    }

    setTreatmentHistoryTherapyPlanCycle(cycle: any, tumorSizeInfoList: any, showOption: any) {
        if (cycle.cycle) {
            let tumorSizeInfo: any = {};
            let cycleDataList = cycle.item_4;
            if (cycle.position_1) {
                tumorSizeInfo[cycle.position_1] = {
                    longDiameter: cycle.long_diameter_1,
                    shortDiameter: cycle.short_diameter_1,
                };
                for (let item of showOption.series) {
                    if (item.name == (cycle.position_1 + "长径")) {
                        item.data.push(cycle.long_diameter_1)
                    }
                    if (item.name == (cycle.position_1 + "短径")) {
                        item.data.push(cycle.short_diameter_1)
                    }
                }
            }
            if (cycleDataList && cycleDataList instanceof Array && cycleDataList.length > 0) {
                for (let data of cycleDataList) {
                    if (data.position_1) {
                        tumorSizeInfo[data.position_1] = {
                            longDiameter: data.long_diameter_1,
                            shortDiameter: data.short_diameter_1,
                        };
                        for (let item of showOption.series) {
                            if (item.name == (data.position_1 + "长径")) {
                                item.data.push(data.long_diameter_1)
                            }
                            if (item.name == (data.position_1 + "短径")) {
                                item.data.push(data.short_diameter_1)
                            }
                        }
                    }
                }
            }
            tumorSizeInfo["cycle"] = cycle.cycle;
            tumorSizeInfo["total"] = cycle.total_1;
            tumorSizeInfo["evaluation"] = cycle.therapeutic_evaluation;
            tumorSizeInfo["remark"] = cycle.remarks;
            showOption.xAxis.data.push(cycle.cycle);
            if (cycle.total_1) {
                showOption.series[0].data.push(cycle.total_1);
            }
            showOption.series[0].markPoint.data.push({
                name: cycle.remarks,
                yAxis: cycle.total_1,
                xAxis: cycle.cycle,
                value: cycle.therapeutic_evaluation,
                itemStyle: {
                    color: this.treatmentEvaluation[cycle.therapeutic_evaluation]
                }
            });
            tumorSizeInfoList.push(tumorSizeInfo);
        }
    }

    setTreatmentHistoryOperation() {
        let operationDataList = this.diagnosisTreatData.filter(item => item.id == "手术");
        for (let operationData of operationDataList) {
            if (operationData && operationData.data && operationData.data.is_operation == 'true') {
                operationData = operationData.data;
                let operationInfoList = operationData.item;
                if (operationInfoList && operationInfoList instanceof Array) {
                    for (let operationInfo of operationInfoList) {
                        this.setOperationInfoToTreatmentHistory(operationInfo);
                    }
                }
                this.setOperationInfoToTreatmentHistory(operationData);
            }
        }
    }

    setOperationInfoToTreatmentHistory(operationData: any) {
        if (operationData.is_operation == 'true' && operationData.operative_time) {
            let children: any = [];
            children.push({
                type: '手术信息',
                surgical_nature: operationData.surgical_nature,
                resection_margin_situations: operationData.resection_margin_situations,
                angioplasty: operationData.angioplasty,
            });
            if (operationData.postoperative_complications) {
                try {
                    operationData.postoperative_complications = JSON.parse(operationData.postoperative_complications);
                } catch (e) {
                    console.log(e);
                    operationData.postoperative_complications = [];
                }
            }
            children.push({
                type: '术后信息',
                wound_pain_grading: operationData.wound_pain_grading,
                postoperative_complications: operationData.postoperative_complications,
                other_complications: operationData.other_complications,
            });
            children.push({
                type: '病理报告',
                pathology_report: operationData.pathology_report,
            });
            let tumorInfo = this.setOperationTumorInfo(operationData);
            children.push(...tumorInfo);
            let lymphNodeMetastasis = false;
            let lymphNodeNotMetastasis = false;
            let lymphNodeNotHarvested = false;
            for (let item of this.lymphNodeDissectionNumber) {
                if (!lymphNodeMetastasis && operationData['total_' + item] != 0 && operationData['number_of_metastases_' + item] != 0) {
                    lymphNodeMetastasis = true;
                }
                if (!lymphNodeNotMetastasis && operationData['total_' + item] != 0 && operationData['number_of_metastases_' + item] == 0) {
                    lymphNodeNotMetastasis = true;
                }
                if (!lymphNodeNotHarvested && operationData['total_' + item] == 0 && operationData['number_of_metastases_' + item] == 0) {
                    lymphNodeNotHarvested = true;
                }
            }
            children.push({
                type: '淋巴结清扫',
                data: operationData,
            });
            let geneTestInfo = this.setOperationGeneTest(operationData);
            children.push(...geneTestInfo);
            this.showTreatmentHistoryData.push({
                startDate: new Date(operationData.operative_time),
                endDate: null,
                type: "手术",
                title: "手术",
                data: operationData,
                children: children,
                showInspect: false,
                isUnfold: false,
                summary: operationData.name_of_surgery,
                stageType: operationData.pathological_stage_type,
                t: operationData.t,
                n: operationData.n,
                m: operationData.m,
                geneTestInfo: geneTestInfo,
                tumorInfo: tumorInfo,
                lymphNodeMetastasis: lymphNodeMetastasis,
                lymphNodeNotMetastasis: lymphNodeNotMetastasis,
                lymphNodeNotHarvested: lymphNodeNotHarvested,
            });
        }
    }

    setOperationTumorInfo(operationData: any) {
        let children: any[] = [];
        if (operationData.tumor_location && operationData.tumor_location_core_peripheral_) {
            operationData.location = operationData.tumor_location + "-" + operationData.tumor_location_core_peripheral_
        } else if (operationData.tumor_location) {
            operationData.location = operationData.tumor_location;
        } else if (operationData.tumor_location_core_peripheral_) {
            operationData.location = operationData.tumor_location_core_peripheral_;
        }
        if (operationData.location) {
            children.push({
                type: '肿瘤',
                data: operationData,
            });
        }
        let tumorList = operationData.item_3;
        if (tumorList && tumorList instanceof Array) {
            for (let tumor of tumorList) {
                if (tumor.tumor_location && tumor.tumor_location_core_peripheral_) {
                    tumor.location = tumor.tumor_location + "-" + tumor.tumor_location_core_peripheral_
                } else if (tumor.tumor_location) {
                    tumor.location = tumor.tumor_location;
                } else if (tumor.tumor_location_core_peripheral_) {
                    tumor.location = tumor.tumor_location_core_peripheral_;
                }
                if (tumor.location) {
                    children.push({
                        type: '肿瘤',
                        data: tumor,
                    });
                }
            }
        }
        return children;
    }

    setOperationGeneTest(operationData: any) {
        let children: any[] = [];
        for (let genetic of this.geneticTest) {
            if (operationData[genetic + '_detection'] && operationData[genetic + '_detection'] == 'true') {
                children.push({
                    type: '基因检测',
                    title: genetic.toUpperCase() + '基因检测',
                    class: genetic,
                    data: operationData,
                });
            }
        }
        return children;
    }

    setTreatmentHistoryRecrudescence() {
        let recrudescenceDataList = this.diagnosisTreatData.filter(item => item.id == "复发或转移");
        for (let recrudescenceData of recrudescenceDataList) {
            if (recrudescenceData && recrudescenceData.data) {
                recrudescenceData = recrudescenceData.data;
                if (recrudescenceData.whether_recrudescence == 'true' && recrudescenceData.time_to_recurrence) {
                    this.showTreatmentHistoryData.push({
                        startDate: new Date(recrudescenceData.time_to_recurrence),
                        endDate: null,
                        type: "复发或转移",
                        title: "复发或转移",
                        data: recrudescenceData,
                        showInspect: false,
                        children: [{
                            type: '复发',
                            data: recrudescenceData,
                        }],
                        isUnfold: false
                    });
                }
            }
        }
    }

    setKeyDiagnosisTreatmentData() {
        let keyDiagnosisTreatmentForm = this.diagnosisTreatData.find(item => item.id == "关键诊疗信息补充");
        if (keyDiagnosisTreatmentForm && keyDiagnosisTreatmentForm.data) {
            keyDiagnosisTreatmentForm = keyDiagnosisTreatmentForm.data;
            let keyDiagnosisTreatmentDataList = keyDiagnosisTreatmentForm.item;
            if (keyDiagnosisTreatmentDataList && keyDiagnosisTreatmentDataList instanceof Array) {
                for (let keyDiagnosisTreatmentData of keyDiagnosisTreatmentDataList) {
                    if (keyDiagnosisTreatmentData.name && keyDiagnosisTreatmentData.date) {
                        this.showTreatmentHistoryData.push({
                            startDate: new Date(keyDiagnosisTreatmentData.date),
                            endDate: null,
                            type: "关键诊疗数据",
                            data: keyDiagnosisTreatmentData,
                            title: keyDiagnosisTreatmentData.name,
                            summary: keyDiagnosisTreatmentData.summary_information,
                            inspectionNo: keyDiagnosisTreatmentData.inspection_application_no,
                            detaileInfo: keyDiagnosisTreatmentData.detail_information,
                            isUnfold: false
                        });
                    }
                }
            }
            if (keyDiagnosisTreatmentForm.name && keyDiagnosisTreatmentForm.date) {
                this.showTreatmentHistoryData.push({
                    startDate: new Date(keyDiagnosisTreatmentForm.date),
                    endDate: null,
                    type: "关键诊疗数据",
                    data: keyDiagnosisTreatmentForm,
                    summary: keyDiagnosisTreatmentForm.summary_information,
                    title: keyDiagnosisTreatmentForm.name,
                    inspectionNo: keyDiagnosisTreatmentForm.inspection_application_no,
                    detaileInfo: keyDiagnosisTreatmentForm.detail_information,
                    isUnfold: false
                });
            }
        }
    }

    setExaminationBeforeTreatData() {
        if (this.examinationBeforeTreatment) {
            if (this.examinationBeforeTreatment.chest_ct_report && this.examinationBeforeTreatment.date) {
                this.showTreatmentHistoryData.push({
                    startDate: new Date(this.examinationBeforeTreatment.date),
                    endDate: null,
                    type: "关键诊疗数据",
                    data: null,
                    title: "CT",
                    summary: this.examinationBeforeTreatment.summary,
                    inspectionNo: this.examinationBeforeTreatment.inspection_application_no,
                    detaileInfo: this.examinationBeforeTreatment.chest_ct_report,
                    isUnfold: false
                });
            }
            if (this.examinationBeforeTreatment.pet_ct_content && this.examinationBeforeTreatment.date_1 && this.examinationBeforeTreatment.pretreatment_pet_ct == 'true') {
                this.showTreatmentHistoryData.push({
                    startDate: new Date(this.examinationBeforeTreatment.date_1),
                    endDate: null,
                    type: "关键诊疗数据",
                    data: null,
                    title: "PET/CT",
                    summary: this.examinationBeforeTreatment.summary_1,
                    inspectionNo: this.examinationBeforeTreatment.inspection_application_no_1,
                    detaileInfo: this.examinationBeforeTreatment.pet_ct_content,
                    isUnfold: false
                });
            }
            if (this.examinationBeforeTreatment.pathology_report && this.examinationBeforeTreatment.date_2 && this.examinationBeforeTreatment.pre_treatment_pathology == 'true') {
                this.showTreatmentHistoryData.push({
                    startDate: new Date(this.examinationBeforeTreatment.date_2),
                    endDate: null,
                    type: "关键诊疗数据",
                    data: null,
                    title: "病理",
                    summary: this.examinationBeforeTreatment.summary_2,
                    inspectionNo: null,
                    detaileInfo: this.examinationBeforeTreatment.pathology_report,
                    isUnfold: false
                });
            }
        }
    }

    setTreatmentHistoryInspect() {
        for (let i = 1; i < this.showTreatmentHistoryData.length; i++) {
            let inspect: any = {
                CT: this.inspectionDataList.filter(inspect => inspect.dateTimeIssued >= this.showTreatmentHistoryData[i].startDate && inspect.dateTimeIssued <= this.showTreatmentHistoryData[i].endDate && inspect.examClassName == 'CT'),
                PET: this.inspectionDataList.filter(inspect => inspect.dateTimeIssued >= this.showTreatmentHistoryData[i].startDate && inspect.dateTimeIssued <= this.showTreatmentHistoryData[i].endDate && inspect.examClassName == 'PET'),
                pathology: this.inspectionDataList.filter(inspect => inspect.dateTimeIssued >= this.showTreatmentHistoryData[i].startDate && inspect.dateTimeIssued <= this.showTreatmentHistoryData[i].endDate && inspect.examClassName == '病理'),
                other: this.inspectionDataList.filter(inspect => inspect.dateTimeIssued >= this.showTreatmentHistoryData[i].startDate && inspect.dateTimeIssued <= this.showTreatmentHistoryData[i].endDate && inspect.examClassName != 'CT' && inspect.examClassName != 'PET' && inspect.examClassName != '病理'),
            };
            let existenceInspect: boolean = (inspect.CT && inspect.CT.length > 0) || (inspect.PET && inspect.PET.length > 0) || (inspect.pathology && inspect.pathology.length > 0) || (inspect.other && inspect.other.length > 0);
            this.showTreatmentHistoryData[i].inspect = inspect;
            this.showTreatmentHistoryData[i].existenceInspect = existenceInspect;
        }
        let inspect: any = {
            CT: this.inspectionDataList.filter(inspect => inspect.dateTimeIssued <= this.showTreatmentHistoryData[0].endDate && inspect.examClassName == 'CT'),
            PET: this.inspectionDataList.filter(inspect => inspect.dateTimeIssued <= this.showTreatmentHistoryData[0].endDate && inspect.examClassName == 'PET'),
            pathology: this.inspectionDataList.filter(inspect => inspect.dateTimeIssued <= this.showTreatmentHistoryData[0].endDate && inspect.examClassName == '病理'),
            other: this.inspectionDataList.filter(inspect => inspect.dateTimeIssued <= this.showTreatmentHistoryData[0].endDate && inspect.examClassName != 'CT' && inspect.examClassName != 'PET' && inspect.examClassName != '病理'),
        };
        let existenceInspect: boolean = (inspect.CT && inspect.CT.length > 0) || (inspect.PET && inspect.PET.length > 0) || (inspect.pathology && inspect.pathology.length > 0) || (inspect.other && inspect.other.length > 0);
        this.showTreatmentHistoryData[0].inspect = inspect;
        this.showTreatmentHistoryData[0].existenceInspect = existenceInspect;
    }

    async setPatientBasicInfo() {
        let currentPatient = await this.patientService.getPatientById(this.patientId).toPromise() as any;
        let date = new Date();
        currentPatient.age = this.utils.getAgeByDateStr(currentPatient.birthdate, date.toString());
        this.showTreatmentHistoryData.unshift({
            title: "患者信息",
            type: "患者信息",
            summary: this.patientBasicInfo.diagnosis,
            patientBasicInfo: this.patientBasicInfo,
            medicalHistory: this.medicalHistory,
            examinationBeforeTreatment: this.examinationBeforeTreatment,
            diseaseHistoryList: this.diseaseHistoryList,
            currentPatient: currentPatient
        })
    }

    unfoldTimeline() {
        for (let item of this.showTreatmentHistoryData) {
            item.showInspect = true;
            item.isUnfold = true;
        }
        for (let item of this.inspectionDataList) {
            item.isUnfold = true;
        }
    }

    shrinkTimeline() {
        for (let item of this.showTreatmentHistoryData) {
            item.showInspect = false;
            item.isUnfold = false;
        }
        for (let item of this.inspectionDataList) {
            item.isUnfold = false;
        }
    }

    backToPatientView() {
        this.router.navigate(['patient/view'], { queryParams: { patientIdentifier: this.patientIdentifier, patientId: this.patientId } });
    }

    showAppDiagnosisTreatModel() {
        window.open('#/diagnosis/treat?patientIdentifier=' + this.patientIdentifier + '&showInDiagnosisTreat=true&patientId=' + this.patientId, '_blank');
    }
}
