import { Component, OnInit, ViewChild } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';

import { Utils } from '../core/utils/utils.service';
import { PatientMeetingRecord, PatientService } from "../core/service/patient.service";
import { NzMessageService } from "ng-zorro-antd/message";


@Component({
    selector: 'app-patient-view',
    templateUrl: './patient-view.component.html',
    styleUrls: ['./patient-view.component.css']
})
export class PatientViewComponent implements OnInit {

    @ViewChild("appClincTestRecommend") appClincTestRecommend: any;
    @ViewChild("appClinicalGuideline") appClinicalGuideline: any;
    @ViewChild("appStage") appStage: any;
    @ViewChild("appGeneUnscramble") appGeneUnscramble: any;
    @ViewChild("appDiagnosisTreat") appDiagnosisTreat: any;
    patientId: string;
    patientIdentifier: string;
    visibleRecordDrawer = false;
    lastDiscussResult: string;

    currentRecord: PatientMeetingRecord = new PatientMeetingRecord();
    currentPatient: any = {};
    isShowAddRecord = false;
    isEditRecord = false;

    recordList: PatientMeetingRecord[] = [];


    constructor(private utils: Utils,
        private router: Router,
        private route: ActivatedRoute,
        private patientService: PatientService,
        private _message: NzMessageService) {
        this.route.queryParams.subscribe((res) => {
            this.patientId = res.patientId;
            this.patientIdentifier = res.patientIdentifier;
        });
    }

    async ngOnInit() {
        this.currentPatient = await this.patientService.getPatientById(this.patientId).toPromise() as any;
        this.setRecordList();
        this.formatPatient();
    }

    async setRecordList() {
        this.recordList = this.currentPatient.recordList;
    }

    formatPatient() {
        let date = new Date()
        this.currentPatient.age = this.utils.getAgeByDateStr(this.currentPatient.birthdate, date.toString());
        this.currentPatient.iconText = this.currentPatient.patientName.substring(0, 1);
    }



    clinicTestDetailPage() {
        this.appClincTestRecommend.clinicalTestDetailPageModelVisible = true;
        this.appClincTestRecommend.getClinicalTestDataList();
    }

    stageDetailPage() {
        this.appStage.showStageDetailPageModel();
    }

    gulidelineDetailPage() {
        this.appClinicalGuideline.guidelineDetailPageModelVisible = true;
    }

    showAppDiagnosisTreatModel() {
        this.router.navigate(['diagnosis/treat'], { queryParams: { patientIdentifier: this.patientIdentifier, showInDiagnosisTreat: true, patientId: this.patientId} });
    }

    openRecordDrawer(): void {
        this.visibleRecordDrawer = true;
    }

    closeRecordDrawer(): void {
        this.visibleRecordDrawer = false;
    }

    showAddRecord() {
        if (this.currentPatient.recordList && this.currentPatient.recordList.length > 0 && this.currentPatient.recordList[this.currentPatient.recordList.length - 1].discussResult == null) {
            this._message.error("还没有填写上一次的讨论结果，请填写后添加");
        } else {
            this.isShowAddRecord = true;
        }
    }

    editRecord() {
        this.isShowAddRecord = true;
        this.currentRecord = this.currentPatient.recordList.splice(this.currentPatient.recordList.length - 1)[0];
        this.isEditRecord = true
    }

    geneUnscrambleDetailPage(){
        this.appGeneUnscramble.isVisiblePdf = true;
    }

    async addRecord() {
        if (this.isEditRecord) {

        } else {
            this.currentRecord.recordCreatorId = Number(sessionStorage.getItem("user_id"));
            this.currentRecord.recordCreatorName = sessionStorage.getItem("user_name")!;
            this.currentRecord.recordPatientId = this.currentPatient.patientId;
            this.currentRecord = await this.patientService.addPatientMeetingRecord(this.currentRecord).toPromise() as any;
            this._message.success('添加成功');
        }
        this.lastDiscussResult = '';
        this.isShowAddRecord = false;
        this.currentPatient.recordList.push(this.currentRecord);
        this.currentRecord = new PatientMeetingRecord();
        this.setRecordList();
    }

    uneditedRecord() {
        this.isShowAddRecord = false;
        this.isEditRecord = false;
        this.currentPatient.recordList.push(this.currentRecord);
        this.currentRecord = new PatientMeetingRecord();
        this.setRecordList();
    }

    async updateRecordDiscussResult() {
        let lastRecord = this.currentPatient.recordList[this.currentPatient.recordList.length - 1];
        lastRecord.discussResult = this.lastDiscussResult;
        let result = await this.patientService.updatePatientMeetingRecord(lastRecord).toPromise() as any;
        lastRecord.recordDate = result.recordDate;
        this._message.success('修改成功');
        this.setRecordList();
    }
}
