import { Component, OnInit } from '@angular/core';
import { PercentPipe } from '@angular/common';
import { PatientService } from './../../core/service/patient.service';
import { StagePredictService } from './../../core/service/stage-predict.service';
import {PrognosisEvaluationService} from "../../core/service/prognosis-evaluation.service";

@Component({
    selector: 'app-prognosis-assess',
    templateUrl: './prognosis-assess.component.html',
    styleUrls: ['./prognosis-assess.component.css']
})
export class PrognosisAssessComponent implements OnInit {
    examAndTestFormData: any = {};
    postoperativePathlogyFormData: any = {};
    postoperativePathlogyFormStatus: any;

    patientBasicFormData: any = {};
    medicalHistoryFormData: any = {};
    operationFormData: any = {};
    diagnosisTreatData: any[] = [];

    prognosisEvaluationData: any;
    prognosisEvaluationDataLoading = false;
    colors = ['#c23531','#F0CCCC', '#91CC75', '#CCEFDC'];
    options: any[] = [];
    riskFactorsCoefficientAttributionNames = ['oneRecurrence', 'oneSurvival', 'threeRecurrence', 'threeSurvival', 'fiveRecurrence', 'fiveSurvival'];
    prognosisEvaluationNames = ['一年内复发风险因子', '一年内死亡风险因子', '三年内复发风险因子', '三年内死亡风险因子', '五年内复发风险因子', '五年内死亡风险因子'];
    nsclcPrognosisStatisticProbabilityNames = ['oneYearRecurrenceProbability', 'oneYearDeathProbability', 'threeYearRecurrenceProbability', 'threeYearDeathProbability', 'fiveYearRecurrenceProbability', 'fiveYearDeathProbability']
    nsclcPrognosisStatisticNumberNames = ['oneYearRecurrenceNumber', 'oneYearDeathNumber', 'threeYearRecurrenceNumber', 'threeYearDeathNumber', 'fiveYearRecurrenceNumber', 'fiveYearDeathNumber'];
    nsclcPrognosisStatisticsTooltips: any = [];

    constructor(private patientService: PatientService,
                private stagePredictService: StagePredictService,
                private percentPipe: PercentPipe,
                private prognosisEvaluationService: PrognosisEvaluationService) { }

    ngOnInit(): void {
        // 订阅患者诊疗数据的变化
        this.patientService.diagnosisTreatDataSubject$.subscribe((diagnosisTreatData: any) => {
            this.diagnosisTreatData = diagnosisTreatData;
            let examAndTestFormData = this.diagnosisTreatData.find(item => item.id == "治疗前检查检验");
            if (examAndTestFormData && examAndTestFormData.data) {
                this.examAndTestFormData = examAndTestFormData.data;
            }


            let patientBasicFormData = this.diagnosisTreatData.find(item => item.id == "患者当前基本信息");
            if (patientBasicFormData && patientBasicFormData.data) {
                this.patientBasicFormData = patientBasicFormData.data;
            }

            let medicalHistoryFormData = this.diagnosisTreatData.find(item => item.id == "病史信息");
            if (medicalHistoryFormData && medicalHistoryFormData.data) {
                this.medicalHistoryFormData = medicalHistoryFormData.data;
            }

            let operationFormDataList = this.diagnosisTreatData.filter(item => item.id == "手术" && item.data != null && item.data.operative_time != null);
            if (operationFormDataList && operationFormDataList.length > 0) {
                operationFormDataList.sort(function (a: any, b: any) {
                    return b.data.operative_time - a.data.operative_time
                });
                this.operationFormData = operationFormDataList[0].data;
                this.postoperativePathlogyFormData = operationFormDataList[0].data;
                // 表单录入状态，1为未录入，2为未完成，3为已完成
                this.postoperativePathlogyFormStatus = operationFormDataList[0].metadata.formEntryStatus;
                this.prognosisEvaluation();
            } else {
                this.postoperativePathlogyFormStatus = 1;
            }
        });
    }

    prognosisEvaluation() {
        let data = {
            patientId: this.patientBasicFormData.patient_id ? this.patientBasicFormData.patient_id : "",
            "性别": this.patientBasicFormData.gender,
            "年龄": this.patientBasicFormData.age ? this.patientBasicFormData.age : 0,
            "吸烟史": this.medicalHistoryFormData.is_smoking_history == 'true' ? '有' : '无',
            "饮酒史": this.medicalHistoryFormData.is_drinking_history == 'true' ? '有' : '无',
            "肿瘤史": this.medicalHistoryFormData.is_tumor_history == 'true' ? '有' : '无',
            "家族史": this.medicalHistoryFormData.is_family_history == 'true' ? '有' : '无',
            "治疗前病理": this.examAndTestFormData.pre_treatment_pathology == 'true' ? '有' : '无',
            "PET/CT": this.examAndTestFormData.pretreatment_pet_ct == 'true' ? '有' : '无',
            "术前治疗": this.examAndTestFormData.whether_preoperative_neoadjuvant_therapy == 'true' ? '有' : '无',
            "手术方式2": this.operationFormData.surgical_approach,
            "成形手术": this.operationFormData.plastic_surgery == 'true' ? '有' : '无',
            "肿瘤位置": this.postoperativePathlogyFormData.tumor_location,
            "肿瘤大小": this.postoperativePathlogyFormData.tumor_long_diameter ? this.postoperativePathlogyFormData.tumor_long_diameter : 0,
            "病理类型": this.postoperativePathlogyFormData.pathological_types,
            "分化程度": this.postoperativePathlogyFormData.degree_of_differentiation,
            "脉管癌栓": this.postoperativePathlogyFormData.vascular_cancer_thrombus == 'true' ? 1 : 0,
            "胸膜侵犯": this.postoperativePathlogyFormData.pleural_invasion == 'true' ? 1 : 0,
            "1L转移数": this.postoperativePathlogyFormData.number_of_metastases_1l ? this.postoperativePathlogyFormData.number_of_metastases_1l : 0,
            "1L总数": this.postoperativePathlogyFormData.total_1l ? this.postoperativePathlogyFormData.total_1l : 0,
            "1R转移数": this.postoperativePathlogyFormData.number_of_metastases_1r ? this.postoperativePathlogyFormData.number_of_metastases_1r : 0,
            "1R总数": this.postoperativePathlogyFormData.total_1r ? this.postoperativePathlogyFormData.total_1r : 0,
            "2L转移数": this.postoperativePathlogyFormData.number_of_metastases_2l ? this.postoperativePathlogyFormData.number_of_metastases_2l : 0,
            "2L总数": this.postoperativePathlogyFormData.total_2l ? this.postoperativePathlogyFormData.total_2l : 0,
            "2R转移数": this.postoperativePathlogyFormData.number_of_metastases_2r ? this.postoperativePathlogyFormData.number_of_metastases_2r : 0,
            "2R总数": this.postoperativePathlogyFormData.total_2r ? this.postoperativePathlogyFormData.total_2r : 0,
            "2R+4R转移数": this.postoperativePathlogyFormData.number_of_metastases_2r_4r ? this.postoperativePathlogyFormData.number_of_metastases_2r_4r : 0,
            "2R+4R总数": this.postoperativePathlogyFormData.total_2r_4r ? this.postoperativePathlogyFormData.total_2r_4r : 0,
            "3A转移数": this.postoperativePathlogyFormData.number_of_metastases_3a ? this.postoperativePathlogyFormData.number_of_metastases_3a : 0,
            "3A总数": this.postoperativePathlogyFormData.total_3a ? this.postoperativePathlogyFormData.total_3a : 0,
            "3P转移数": this.postoperativePathlogyFormData.number_of_metastases_3p ? this.postoperativePathlogyFormData.number_of_metastases_3p : 0,
            "3P总数": this.postoperativePathlogyFormData.total_3p ? this.postoperativePathlogyFormData.total_3p : 0,
            "4L转移数": this.postoperativePathlogyFormData.number_of_metastases_4l ? this.postoperativePathlogyFormData.number_of_metastases_4l : 0,
            "4L总数": this.postoperativePathlogyFormData.total_4l ? this.postoperativePathlogyFormData.total_4l : 0,
            "4R转移数": this.postoperativePathlogyFormData.number_of_metastases_4r ? this.postoperativePathlogyFormData.number_of_metastases_4r : 0,
            "4R总数": this.postoperativePathlogyFormData.total_4r ? this.postoperativePathlogyFormData.total_4r : 0,
            "5转移数": this.postoperativePathlogyFormData.number_of_metastases_5 ? this.postoperativePathlogyFormData.number_of_metastases_5 : 0,
            "5总数": this.postoperativePathlogyFormData.total_5 ? this.postoperativePathlogyFormData.total_5 : 0,
            "6转移数": this.postoperativePathlogyFormData.number_of_metastases_6 ? this.postoperativePathlogyFormData.number_of_metastases_6 : 0,
            "6总数": this.postoperativePathlogyFormData.total_6 ? this.postoperativePathlogyFormData.total_6 : 0,
            "7转移数": this.postoperativePathlogyFormData.number_of_metastases_7 ? this.postoperativePathlogyFormData.number_of_metastases_7 : 0,
            "7总数": this.postoperativePathlogyFormData.total_7 ? this.postoperativePathlogyFormData.total_7 : 0,
            "8转移数": this.postoperativePathlogyFormData.number_of_metastases_8 ? this.postoperativePathlogyFormData.number_of_metastases_8 : 0,
            "8总数": this.postoperativePathlogyFormData.total_8 ? this.postoperativePathlogyFormData.total_8 : 0,
            "9转移数": this.postoperativePathlogyFormData.number_of_metastases_9 ? this.postoperativePathlogyFormData.number_of_metastases_9 : 0,
            "9总数": this.postoperativePathlogyFormData.total_9 ? this.postoperativePathlogyFormData.total_9 : 0,
            "10转移数": this.postoperativePathlogyFormData.number_of_metastases_10 ? this.postoperativePathlogyFormData.number_of_metastases_10 : 0,
            "10总数": this.postoperativePathlogyFormData.total_10 ? this.postoperativePathlogyFormData.total_10 : 0,
            "11转移数": this.postoperativePathlogyFormData.number_of_metastases_11 ? this.postoperativePathlogyFormData.number_of_metastases_11 : 0,
            "11总数": this.postoperativePathlogyFormData.total_11 ? this.postoperativePathlogyFormData.total_11 : 0,
            "12转移数": this.postoperativePathlogyFormData.number_of_metastases_12 ? this.postoperativePathlogyFormData.number_of_metastases_12 : 0,
            "12总数": this.postoperativePathlogyFormData.total_12 ? this.postoperativePathlogyFormData.total_12 : 0,
            "13转移数": this.postoperativePathlogyFormData.number_of_metastases_13 ? this.postoperativePathlogyFormData.number_of_metastases_13 : 0,
            "13总数": this.postoperativePathlogyFormData.total_13 ? this.postoperativePathlogyFormData.total_13 : 0,
            "14转移数": this.postoperativePathlogyFormData.number_of_metastases_14 ? this.postoperativePathlogyFormData.number_of_metastases_14 : 0,
            "14总数": this.postoperativePathlogyFormData.total_14 ? this.postoperativePathlogyFormData.total_14 : 0,
            "N分期": this.getPn(this.postoperativePathlogyFormData.n),
            "新T分期": this.getPt(this.postoperativePathlogyFormData.t)
        };
        this.prognosisEvaluationDataLoading = true;
        this.stagePredictService.prognosisEvaluationByPatientData(data).subscribe(res => {
            this.prognosisEvaluationData = res;
            for (let item in this.prognosisEvaluationData) {
                if (this.prognosisEvaluationData[item]) {
                    this.prognosisEvaluationData[item] = this.percentPipe.transform(this.prognosisEvaluationData[item]);
                } else {
                    this.prognosisEvaluationData[item] = '暂无'
                }
            }
            this.prognosisEvaluationDataLoading = false;
        }, ((error: any) => { this.prognosisEvaluationDataLoading = false; }));
        this.prognosisEvaluationService.getPrognosisEvaluationInfo().subscribe(res  => {
            let result: any = res;
            this.setRiskFactors(result);
            this.setNsclcPrognosisStatistics(result);
        });
    }
    setNsclcPrognosisStatistics(result: any) {
        let nsclcPrognosisStatistics : any[] = result.NsclcPrognosisStatistics
        let stage = '';
        if (this.stagePredictService.stage) {
            stage = this.stagePredictService.stage;
        } else if (this.postoperativePathlogyFormData && this.postoperativePathlogyFormData.stage) {
            stage = this.postoperativePathlogyFormData.stage;
        } else if (this.examAndTestFormData && this.examAndTestFormData.stage) {
            stage = this.examAndTestFormData.stage;
        }
        let allStatistic = nsclcPrognosisStatistics.find(item => item.stage == 'All');
        for (let index = 0; index < this.nsclcPrognosisStatisticProbabilityNames.length; index++) {
            let year;
            switch (index) {
                case 0 :
                case 1 :
                    year = '一年内';
                    break;
                case 2 :
                case 3 :
                    year = '三年内';
                    break;
                case 4 :
                case 5 :
                    year = '五年内';
            }
            let situation;
            if (index%2 == 0 ) {
                situation = '复发';
            } else {
                situation = '死亡';
            }
            let tooltipTitle = year + "平均" + situation + "概率为" +  Number(allStatistic[this.nsclcPrognosisStatisticProbabilityNames[index]] * 100).toFixed(1) + "%(" + allStatistic[this.nsclcPrognosisStatisticNumberNames[index]] + "/" + allStatistic.total + ")";
            let stageStatistic = nsclcPrognosisStatistics.find(item => item.stage.toUpperCase() == stage);
            if (stageStatistic) {
                tooltipTitle += '，' + stage + '期患者平均' + situation + '概率为' + Number(stageStatistic[this.nsclcPrognosisStatisticProbabilityNames[index]] * 100).toFixed(1) + "%(" + stageStatistic[this.nsclcPrognosisStatisticNumberNames[index]] + "/" + stageStatistic.total + ")";
            }
            this.nsclcPrognosisStatisticsTooltips.push(tooltipTitle);
        }

    }

    setRiskFactors(result: any) {
        let averagedFeatureImportance = result.AveragedFeatureImportanceInfo;
        let colorList: any[] = [];
        for (let i = 0; i < this.riskFactorsCoefficientAttributionNames.length; i++) {
            let sortName = this.riskFactorsCoefficientAttributionNames[i];
            averagedFeatureImportance.sort(function (a: any, b: any) {
                return a[sortName] - b[sortName]
            });
            let riskFactors: any[] = [];
            //获取风险因子
            riskFactors.push(...averagedFeatureImportance.slice(0, 10));
            riskFactors.push(...averagedFeatureImportance.slice(-10));
            let colors: any[] = [];
            for (let riskFactorsIndex = 0; riskFactorsIndex < riskFactors.length; riskFactorsIndex++) {
                let riskFactor = riskFactors[riskFactorsIndex];
                let form = this.diagnosisTreatData.find(form => form.id == riskFactor.macthTableName);
                colors.push(this.judgeRiskFactorColor(riskFactor, form, riskFactorsIndex));
            }
            colorList.push(colors);
            let option: any = {
                title: {
                    text: '一年内复发',
                    left: '50%',
                    textAlign: 'center'
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {            // 坐标轴指示器，坐标轴触发有效
                        type: 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
                    }
                },
                grid: {
                    top: 60,
                    bottom: 0,
                    left: 160,
                },
                xAxis: {
                    type: 'value',
                    position: 'top',
                    splitLine: {
                        lineStyle: {
                            type: 'dashed'
                        }
                    }
                },
                yAxis: {
                    type: 'category',
                    axisTick: {
                        show: false
                    },
                    data: []
                },
                series: [
                    {
                        name: '风险因子',
                        type: 'bar',
                        stack: '总量',
                        emphasis: {
                            focus: 'series'
                        },
                        itemStyle: {
                            normal:{
                                color: function(params: any){
                                    return colorList[i][params.dataIndex];
                                }
                            }
                        },
                        data: []
                    },
                ]
            };
            option.title.text = this.prognosisEvaluationNames[i];
            option.yAxis.data = riskFactors.map(item => item.riskFactorsName);
            option.series[0].data = riskFactors.map(item => item[sortName]);
            this.options.push(option);
        }
    }

    judgeRiskFactorColor(riskFactor: any, form: any, riskFactorsIndex: number) {
        let isMatch = false;
        //判断表单数据是否存在
        if (form && form.data) {
            //判断匹配条件为相等还是不等, 然后对值进行匹配
            if (riskFactor.equalsColumnValue == 1 && form.data[riskFactor.macthColumnName] == riskFactor.macthColumnValue) {
                isMatch = true;
            } else if (riskFactor.equalsColumnValue == 0 && form.data[riskFactor.macthColumnName] != riskFactor.macthColumnValue) {
                isMatch = true;
            }
            if (isMatch && riskFactor.additionalMacthColumnName) {
                if (riskFactor.additionalEqualsColumnValue == 1 && form.data[riskFactor.additionalMacthColumnName] != riskFactor.additionalMacthColumnValue) {
                    isMatch = false;
                } else if (riskFactor.additionalEqualsColumnValue == 0 && form.data[riskFactor.additionalMacthColumnName] == riskFactor.additionalMacthColumnValue) {
                    isMatch = false;
                }
            }
        }
        if (isMatch) {
            if (riskFactorsIndex < 10) {
                return "#91CC75";
            } else {
                return "#c23531";
            }
        } else {
            if (riskFactorsIndex < 10) {
                return "#CCEFDC";
            } else {
                return "#F0CCCC";
            }
        }
    }

    getPn(pn: string) {
        if (pn) {
            return pn.substring(1);
        } else {
            return 0;
        }
    }

    getPt(pt: string) {
        if (pt) {
            return pt.substring(1);
        } else {
            return '';
        }
    }
}
