import { Component, OnInit } from '@angular/core';
import { PatientService } from './../../core/service/patient.service';
import { StagePredictService } from './../../core/service/stage-predict.service';

@Component({
    selector: 'app-stage',
    templateUrl: './stage.component.html',
    styleUrls: ['./stage.component.css']
})
export class StageComponent implements OnInit {
    stageDetailPageModelVisible = false;
    examAndTestFormData: any = {};
    postoperativePathlogyFormData: any = {};
    postoperativePathlogyFormStatus: any;
    patientBasicFormData: any = {};
    medicalHistoryFormData: any = {};
    diagnosisTreatData: any[] = [];
    tnStagePredict: any;

    stagePredictResultLoading: boolean = false;

    constructor(private patientService: PatientService, private stagePredictService: StagePredictService) { }

    ngOnInit(): void {
        // 订阅患者诊疗数据的变化
        this.patientService.diagnosisTreatDataSubject$.subscribe((diagnosisTreatData: any) => {
            this.diagnosisTreatData = diagnosisTreatData;
            let stage;
            let examAndTestFormData = this.diagnosisTreatData.find(item => item.id == "治疗前检查检验");
            if (examAndTestFormData && examAndTestFormData.data) {
                this.examAndTestFormData = examAndTestFormData.data;
                stage = this.examAndTestFormData.stage;
            }

            let operationFormDataList = this.diagnosisTreatData.filter(item => item.id == "手术" && item.data != null && item.data.operative_time != null);
            if (operationFormDataList && operationFormDataList.length > 0) {
                operationFormDataList.sort(function (a: any, b: any) {
                    return b.data.operative_time - a.data.operative_time
                });
                this.postoperativePathlogyFormData = operationFormDataList[0].data;
                // 表单录入状态，1为未录入，2为未完成，3为已完成
                this.postoperativePathlogyFormStatus = operationFormDataList[0].metadata.formEntryStatus;
                if (this.postoperativePathlogyFormData.stage) {
                    stage = this.postoperativePathlogyFormData.stage;
                }
            } else {
                this.postoperativePathlogyFormStatus = 1;
            }

            let patientBasicFormData = this.diagnosisTreatData.find(item => item.id == "患者当前基本信息");
            if (patientBasicFormData && patientBasicFormData.data) {
                this.patientBasicFormData = patientBasicFormData.data;
                if (this.patientBasicFormData.ecog) {
                    this.stagePredictService.ecog = this.patientBasicFormData.ecog;
                }
            }
            this.stagePredictService.stage = stage;
            this.stagePredictService.announceStageData(stage);

            let medicalHistoryFormData = this.diagnosisTreatData.find(item => item.id == "病史信息");
            if (medicalHistoryFormData && medicalHistoryFormData.data) {
                this.medicalHistoryFormData = medicalHistoryFormData.data;
            }
            // 如果已经存在病理分期，则不需要做分期预测
            if (this.postoperativePathlogyFormStatus != 3) {
                this.stagePredict();
            }
        });
    }

    showStageDetailPageModel() {
        this.stageDetailPageModelVisible = true;
        this.stagePredictResultLoading = true;
        setTimeout(() => {
            this.stagePredictResultLoading = false;
        }, 1500);
    }

    stagePredict() {
        let sideList = ['无', '双侧', '同侧', '异侧'];
        let ctList = [
            { label: 'TX', value: 0 },
            { label: 'T0', value: 0 },
            { label: 'Tis', value: 0 },
            { label: 'T1mi', value: 1 },
            { label: 'T1b', value: 1 },
            { label: 'T1c', value: 1 },
            { label: 'T2a', value: 2 },
            { label: 'T2b', value: 2 },
            { label: 'T3', value: 3 },
            { label: 'T4', value: 4 }]
        let cnList = [
            { label: 'NX', value: 0 },
            { label: 'N0', value: 0 },
            { label: 'N1', value: 1 },
            { label: 'N2', value: 2 },
            { label: 'N3', value: 3 }];

        let data = {
            patientId: this.patientBasicFormData.patient_id,
            "性别": 0,
            "年龄": this.patientBasicFormData.age,
            "SUV_tumor": this.examAndTestFormData.main_tumor_suvmax ? this.examAndTestFormData.main_tumor_suvmax : 0,
            "SUV_lymph_feimen": this.examAndTestFormData.ehln_suvmax ? this.examAndTestFormData.ehln_suvmax : 0,
            "SUV_lymph_zongge": this.examAndTestFormData.meln_suvmax ? this.examAndTestFormData.meln_suvmax : 0,
            "SUV_lymph_suogu": this.examAndTestFormData.caln_suvmax ? this.examAndTestFormData.caln_suvmax : 0,
            "side_feimen": sideList.indexOf(this.examAndTestFormData.ehln_location),
            "side_zongge": sideList.indexOf(this.examAndTestFormData.meln_location),
            "side_suogu": sideList.indexOf(this.examAndTestFormData.caln_location),
            "CEA": this.examAndTestFormData.cea ? this.examAndTestFormData.cea : 0,
            "CA199": this.examAndTestFormData.ca199 ? this.examAndTestFormData.ca199 : 0,
            "CA125": this.examAndTestFormData.ca125 ? this.examAndTestFormData.ca125 : 0,
            "NSE": this.examAndTestFormData.nse ? this.examAndTestFormData.nse : 0,
            "CYFRA21": this.examAndTestFormData.cyfra21_1 ? this.examAndTestFormData.cyfra21_1 : 0,
            "SCC": this.examAndTestFormData.scc ? this.examAndTestFormData.scc : 0,

            "吸烟史": this.medicalHistoryFormData.is_smoking_history == 'true' ? 1 : 0,
            "饮酒史": this.medicalHistoryFormData.is_drinking_history == 'true' ? 1 : 0,
            "肿瘤史": this.medicalHistoryFormData.is_tumor_history == 'true' ? 1 : 0,
            "家族史": this.medicalHistoryFormData.is_family_history == 'true' ? 1 : 0,

            "临床T_category": 0,
            "临床N_category": 0,

            "主肿物位置": this.examAndTestFormData.mt_location ? this.examAndTestFormData.mt_location : '',
            "主肿物长径": this.examAndTestFormData.mt_long_axis ? this.examAndTestFormData.mt_long_axis : 0,
            "主肿物短径": this.examAndTestFormData.mt_short_axis ? this.examAndTestFormData.mt_short_axis : 0,
            "主肿物形状_毛刺": this.examAndTestFormData.mt_shape == "毛刺",
            "主肿物形状_分叶": this.examAndTestFormData.mt_shape == "分叶",
            "主肿物形状_不规则": this.examAndTestFormData.mt_shape == "不规则",
            "主肿物形状_模糊": this.examAndTestFormData.mt_shape == "模糊",
            "主肿物磨玻璃或实性": this.examAndTestFormData.mt_solid_state != "无",
            "有无强化": this.examAndTestFormData.mt_reinforcement == 'true' ? 1 : 0,
            "是否侵犯血管": this.examAndTestFormData.is_invade_macrovascular == 'true' ? 1 : 0,
            "是否侵犯胸膜": this.examAndTestFormData.is_invade_pleura == 'true' ? 1 : 0,
            "是否侵犯支气管": this.examAndTestFormData.is_invade_bronchus == 'true' ? 1 : 0,
            "是否有肺不张或肺阻塞": this.examAndTestFormData.atelectasis_pulmonary_block == 'true' ? 1 : 0,
            "是否有胸水": this.examAndTestFormData.hydrothorax == 'true' ? 1 : 0,
            "锁骨或双腋下淋巴结长径": this.examAndTestFormData.caln_long ? this.examAndTestFormData.caln_long : 0,
            "锁骨或双腋下淋巴结短径": this.examAndTestFormData.caln_short ? this.examAndTestFormData.caln_short : 0,
            "肺门淋巴结长径": this.examAndTestFormData.ehln_long ? this.examAndTestFormData.ehln_long : 0,
            "肺门淋巴结短径": this.examAndTestFormData.ehln_short ? this.examAndTestFormData.ehln_short : 0,
            "纵隔淋巴结长径": this.examAndTestFormData.meln__long ? this.examAndTestFormData.meln__long : 0,
            "纵隔淋巴结短径": this.examAndTestFormData.meln__short ? this.examAndTestFormData.meln__short : 0
        };

        if (this.patientBasicFormData.gender) {
            if (this.patientBasicFormData.gender == '男') {
                data['性别'] = 0;
            } else if (this.patientBasicFormData.gender == '女') {
                data['性别'] = 1;
            }
        }

        if (this.examAndTestFormData.ct) {
            let ct = ctList.find(item => item.label == this.examAndTestFormData.ct);
            if (ct) {
                data['临床T_category'] = ct.value;
            }
            let cn = cnList.find(item => item.label == this.examAndTestFormData.cn);
            if (cn) {
                data['临床N_category'] = cn.value;
            }
        }

        this.stagePredictService.stagePredictByMergeData(data).subscribe(res => {
            this.tnStagePredict = res;
        });
    }

}
