import { Injectable } from '@angular/core';
import { URLService } from "../others/url.service";
import { HttpClient } from "@angular/common/http";
import { PatientImagReportInfo } from "./patient.service";

export class GeneMutationInfo {
    id: number;
    geneName: string;
    detectionContent: string;
    geneFusionMutation: string;
    aminoAcidChange: string;
    nucleotideChange: string;
    exon: string;
    mutationBrief: string;
    carcinogenicity: string;
    therapeuticLevel: string;
    cancerKind: string;
    targetedDrugEn: string;
    targetedDrugCh: string;
    drugList: any;
}

export class GeneGermlineVariant {
    id: number;
    drugNameCh: string;
    drugNameEn: string;
    gene: string;
    phenotype: string;
    desc: string;
    expression: string;
    score: string;
    clinicalImpact: string;
    medicationRecommendations: string;
    classification: string;
    graded: string;
    recommendationGrade: string;
    variantOne: string;
    variantTwo: string;
    pageIndex: number;
}


@Injectable({
    providedIn: 'root'
})

export class GeneMutationService {

    geneReportDataList: PatientImagReportInfo[];

    constructor(private urlService: URLService, private httpClient: HttpClient,) { }

    getAll(pageIndex: string) {
        return this.httpClient.get(this.urlService.URL_GET_ALL_GENE_MUTATION, { params: { pageIndex } });
    }

    getByGene(geneNames: string[], pageIndex: string) {
        return this.httpClient.post(this.urlService.URL_GET_GENE_MUTATION_BY_GENE_NAME, geneNames, { params: { pageIndex } });
    }

    getByDrug(targetedDrugEn: string, pageIndex: string) {
        return this.httpClient.get(this.urlService.URL_GET_GENE_MUTATION_BY_GENE_DRUG, { params: { targetedDrugEn, pageIndex } });
    }

    getSelectInfo() {
        return this.httpClient.get(this.urlService.URL_GET_GENE_MUTATION_SELECT_INFO);
    }

    getVariantSelectInfo(geneGermlineVariant: any) {
        return this.httpClient.post(this.urlService.URL_GET_GENE_VARIANT_SELECT_INFO, geneGermlineVariant);
    }

    getVariantUnscrambleInfo(geneGermlineVariant: any) {
        return this.httpClient.post(this.urlService.URL_GET_VARIANT_UNSCRAMBLE_INFO, geneGermlineVariant);
    }

    getGeneMutationByGeneTestInfo(geneMutationTestInfoList: any, pageIndex: any) {
        return this.httpClient.post(this.urlService.URL_GET_GENE_MUTATION_BY_GENE_TEST_INFO, geneMutationTestInfoList, { params: { pageIndex} });
    }

    getGeneGermlineVariantByGeneTestInfo(geneGermlineVariantList: any) {
        return this.httpClient.post(this.urlService.URL_GET_GENE_GERMLINE_VARIANT_BY_GENE_TEST_INFO, geneGermlineVariantList);
    }

}
