import { Component, OnInit } from '@angular/core';
import {GeneGermlineVariant, GeneMutationInfo, GeneMutationService} from "../../core/service/gene-mutation.service";
import {URLService} from "../../core/others/url.service";
import {PatientService} from "../../core/service/patient.service";

@Component({
    selector: 'app-gene-unscramble',
    templateUrl: './gene-unscramble.component.html',
    styleUrls: ['./gene-unscramble.component.css']
})
export class GeneUnscrambleComponent implements OnInit {


    constructor(public geneMutationService : GeneMutationService,
                public urlSrv : URLService,
                private patientService: PatientService,) { }

    isVisiblePdf: boolean = false;
    selectGene: any;
    selectDrugs: any;
    selectvariantOne: any;
    selectvariantTwo: any;
    geneNameList = [];
    drugNameList = [];
    variantOneList = [];
    variantTwoList = [];
    knowledgeBaseGeneMutationList : GeneMutationInfo[] = [];
    geneMutationList : GeneMutationInfo[] = [];
    geneMutationPageIndex = 1;
    geneMutationTotal = 0;
    knowledgeBaseGeneMutationPageIndex = 1;
    knowledgeBaseGeneMutationTotal: number = 0;
    geneTableLoading = false;
    selectedKnowledgeBase = "体细胞突变与靶向药物";
    mutationSelectInfo : any = {};
    variantSelectInfo : any = {};
    geneNzMode: any = 'multiple';
    //知识库查询化疗药物集合
    knowledgeBaseVariantUnscrambleInfoList: any;
    knowledgeBaseVariantPageIndex = 1;
    knowledgeBaseVariantTotal = 0;
    //化疗药物集合
    variantUnscrambleInfo: any;
    loadingVariantSelectInfo = false;
    geneGermlineVariant = new GeneGermlineVariant();

    treatmentLevelMapping : any = {
        "Level 1": "FDA/NMPA",
        "Level 2": "Guideline",
        "Level 3": "Clinical trial",
        "Level 3A": "Clinical trial",
        "Level 3B": "Clinical trial",
        "Level 4": "Hypothetical",
        "Level R1": "FDA/NMPA",
        "Level R2": "Clinical trial",
    };
    geneMutationTestInfoList: any[] = [];
    geneMutationTestResutlInfo: any = {};
    geneVariantTestInfoList: any[] = [];
    loadGeneMutationList = true;
    //肿瘤突变负荷信息
    tumorMutationLoadList: any[] = [];
    //胚系突变
    germlineMutationList: any[] = [];
    keyTreatData: any;

    async ngOnInit() {
        // 订阅患者诊疗数据的变化
        this.patientService.diagnosisTreatDataSubject$.subscribe((diagnosisTreatData: any) => {
            if (diagnosisTreatData && diagnosisTreatData instanceof Array) {
                this.keyTreatData = diagnosisTreatData.find(item => item.id == "关键诊疗信息补充");
                if (this.keyTreatData && this.keyTreatData.data) {
                    this.keyTreatData = this.keyTreatData.data;
                    //设置靶向药物检测信息
                    this.setGeneMutationTestInfo();
                    this.getGeneMutationList();
                    //设置化疗药物检测信息
                    this.setGeneGermlineVariantTestInfo();
                    this.getGeneGermlineVariantByGeneTestInfo();
                    //设置肿瘤突变负荷信息
                    this.setTumorMutationLoadInfo();
                    //设置胚系突变信息
                    this.setgermlineMutation();
                }
            }
        });
        let geneMutation = new GeneMutationInfo();
        let result : any[] = await Promise.all([
            this.geneMutationService.getSelectInfo().toPromise(),
            this.geneMutationService.getVariantSelectInfo(new GeneGermlineVariant()).toPromise(),
            this.getVariantUnscrambleInfo()
        ]);
        this.mutationSelectInfo = result[0];
        this.geneNameList = result[0]['gene'];
        this.drugNameList = result[0]['drug'];
        this.variantSelectInfo = result[1];
        this.getKnowledgeBaseGeneMutationList();
    }

    changeKnowledgeBase() {
        if (this.selectedKnowledgeBase == '体细胞突变与靶向药物') {
            this.selectGene = [];
            this.selectDrugs = null;
            this.geneNzMode = 'multiple';
        } else {
            this.selectGene = null;
            this.selectDrugs = null;
            this.selectvariantOne = null;
            this.selectvariantTwo = null;
            this.geneNzMode = 'default';
        }
        this.setSelectInfo()
    }

    setSelectInfo() {
        if (this.selectedKnowledgeBase == '体细胞突变与靶向药物') {
            this.geneNameList = this.mutationSelectInfo['gene'];
            this.drugNameList = this.mutationSelectInfo['drug'];
        } else {
            this.geneNameList = this.variantSelectInfo['gene'];
            this.drugNameList = this.variantSelectInfo['drug'];
            this.variantOneList = this.variantSelectInfo['variantOne'];
            this.variantTwoList = this.variantSelectInfo['variantTwo'];
        }
    }

    async getKnowledgeBaseGeneMutationList() {
        //判断知识库类型
        if (this.selectedKnowledgeBase == '体细胞突变与靶向药物') {
            this.knowledgeBaseGeneMutationList = [];
            this.geneTableLoading = true;
            let result;
            if (this.selectGene && this.selectGene.length > 0) {
                result = await this.geneMutationService.getByGene(this.selectGene, this.knowledgeBaseGeneMutationPageIndex.toString()).toPromise() as any;
            } else if (this.selectDrugs) {
                result = await this.geneMutationService.getByDrug(this.selectDrugs, this.knowledgeBaseGeneMutationPageIndex.toString()).toPromise() as any;
            } else {
                result = await this.geneMutationService.getAll(this.knowledgeBaseGeneMutationPageIndex.toString()).toPromise() as any;
            }
            await new Promise((resolve) => setTimeout(resolve, 300));
            this.geneTableLoading = false;
            this.knowledgeBaseGeneMutationTotal = result.total;
            this.knowledgeBaseGeneMutationList = result.list;
        } else {
            this.geneGermlineVariant = new GeneGermlineVariant();
            this.geneGermlineVariant.drugNameEn = this.selectDrugs;
            this.geneGermlineVariant.gene = this.selectGene;
            this.geneGermlineVariant.variantOne = this.selectvariantOne;
            this.geneGermlineVariant.variantTwo = this.selectvariantTwo;
            this.loadingVariantSelectInfo = true;
            this.getVariantUnscrambleInfo();
            this.variantSelectInfo = await this.geneMutationService.getVariantSelectInfo(this.geneGermlineVariant).toPromise() as any;
            this.setSelectInfo();
            this.loadingVariantSelectInfo = false;
        }
    }

    async getVariantUnscrambleInfo() {
        this.geneGermlineVariant.pageIndex = this.knowledgeBaseVariantPageIndex;
        let result = await this.geneMutationService.getVariantUnscrambleInfo(this.geneGermlineVariant).toPromise() as any;
        if (result) {
            this.knowledgeBaseVariantUnscrambleInfoList = result.list;
            this.knowledgeBaseVariantTotal = result.total;
        }
    }

    setGeneMutationTestInfo() {
        if (this.keyTreatData.gene && this.keyTreatData.assay_content && this.keyTreatData.result) {
            let geneMutationTestInfo = new GeneMutationInfo();
            geneMutationTestInfo.geneName = this.keyTreatData.gene;
            geneMutationTestInfo.geneFusionMutation = this.keyTreatData.assay_content;
            this.geneMutationTestResutlInfo[this.keyTreatData.gene + this.keyTreatData.assay_content] = this.keyTreatData.result;
            this.geneMutationTestInfoList.push(geneMutationTestInfo);
        }
        let geneMutationTestDataList = this.keyTreatData.item_2;
        if (geneMutationTestDataList && geneMutationTestDataList instanceof Array) {
            for (let geneMutationTestData of geneMutationTestDataList) {
                if (geneMutationTestData.gene && geneMutationTestData.assay_content && geneMutationTestData.result) {
                    let geneMutationTestInfo = new GeneMutationInfo();
                    geneMutationTestInfo.geneName = geneMutationTestData.gene;
                    geneMutationTestInfo.geneFusionMutation = geneMutationTestData.assay_content;
                    this.geneMutationTestResutlInfo[geneMutationTestData.gene + geneMutationTestData.assay_content] = geneMutationTestData.result;
                    this.geneMutationTestInfoList.push(geneMutationTestInfo);
                }
            }
        }
    }

    setGeneGermlineVariantTestInfo() {
        if (this.keyTreatData.gene_1 && this.keyTreatData.allele_1 && this.keyTreatData.allele_2) {
            let geneVariantTestInfo = new GeneGermlineVariant();
            geneVariantTestInfo.variantOne = this.keyTreatData.allele_1;
            geneVariantTestInfo.variantTwo = this.keyTreatData.allele_2;
            geneVariantTestInfo.gene = this.keyTreatData.gene_1;
            this.geneVariantTestInfoList.push(geneVariantTestInfo);
        }
        let geneVariantTestDataList = this.keyTreatData.item_3;
        if (geneVariantTestDataList && geneVariantTestDataList instanceof Array) {
            for (let geneVariantTestData of geneVariantTestDataList) {
                if (geneVariantTestData.gene_1 && geneVariantTestData.allele_1 && geneVariantTestData.allele_2) {
                    let geneVariantTestInfo = new GeneGermlineVariant();
                    geneVariantTestInfo.variantOne = geneVariantTestData.allele_1;
                    geneVariantTestInfo.variantTwo = geneVariantTestData.allele_2;
                    geneVariantTestInfo.gene = geneVariantTestData.gene_1;
                    this.geneVariantTestInfoList.push(geneVariantTestInfo);
                }
            }
        }
    }

    setTumorMutationLoadInfo() {
        if (this.keyTreatData.sample_1) {
            let tumorMutationLoad: any = {};
            tumorMutationLoad.sample = this.keyTreatData.sample_1;
            tumorMutationLoad.mutations_mb = this.keyTreatData.tmb__mutations_mb_;
            tumorMutationLoad.sort = this.keyTreatData.sort___;
            this.tumorMutationLoadList.push(tumorMutationLoad);
        }
        let tumorMutationLoadDatas = this.keyTreatData.item_5;
        if (tumorMutationLoadDatas && tumorMutationLoadDatas instanceof Array) {
            for (let tumorMutationLoadData of tumorMutationLoadDatas) {
                if (tumorMutationLoadData.sample_1) {
                    let tumorMutationLoad: any = {};
                    tumorMutationLoad.sample = tumorMutationLoadData.sample_1;
                    tumorMutationLoad.mutations_mb = tumorMutationLoadData.tmb__mutations_mb_;
                    tumorMutationLoad.sort = tumorMutationLoadData.sort___;
                    this.tumorMutationLoadList.push(tumorMutationLoad);
                }
            }
        }
    }

    setgermlineMutation() {
        if (this.keyTreatData.gene_2) {
            let germlineMutation: any = {};
            germlineMutation.gene = this.keyTreatData.gene_2;
            germlineMutation.variation = this.keyTreatData.variation;
            germlineMutation.reference_sequences = this.keyTreatData.reference_sequences;
            germlineMutation.state = this.keyTreatData.state;
            germlineMutation.mutation_types = this.keyTreatData.mutation_types;
            germlineMutation.chromosome = this.keyTreatData.chromosome;
            germlineMutation.exons = this.keyTreatData.exons;
            this.germlineMutationList.push(germlineMutation);
        }
        let germlineMutationDatas = this.keyTreatData.item_5;
        if (germlineMutationDatas && germlineMutationDatas instanceof Array) {
            for (let germlineMutationData of germlineMutationDatas) {
                if (germlineMutationData.gene_2) {
                    let germlineMutation: any = {};
                    germlineMutation.gene = germlineMutation.gene_2;
                    germlineMutation.variation = germlineMutationData.variation;
                    germlineMutation.reference_sequences = germlineMutationData.reference_sequences;
                    germlineMutation.state = germlineMutationData.state;
                    germlineMutation.mutation_types = germlineMutationData.mutation_types;
                    germlineMutation.chromosome = germlineMutationData.chromosome;
                    germlineMutation.exons = germlineMutationData.exons;
                    this.germlineMutationList.push(germlineMutation);
                }
            }
        }
    }

    async getGeneMutationList() {
        this.loadGeneMutationList= true;
        if (this.geneMutationTestInfoList && this.geneMutationTestInfoList.length > 0) {
            let result = await this.geneMutationService.getGeneMutationByGeneTestInfo(this.geneMutationTestInfoList, this.geneMutationPageIndex).toPromise() as any;
            this.geneMutationList = result.list;
            this.geneMutationTotal = result.total;
        }
        this.loadGeneMutationList= false;
    }

    async getGeneGermlineVariantByGeneTestInfo() {
        if (this.geneVariantTestInfoList && this.geneVariantTestInfoList.length > 0) {
            let result = await this.geneMutationService.getGeneGermlineVariantByGeneTestInfo(this.geneVariantTestInfoList).toPromise() as any;
            this.variantUnscrambleInfo = result;
        }
    }

}
